; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional -- defaults to 15 if omitted)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas.
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /DB, a   ;hold down-back while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   You can combine them:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;   It's recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This matches the way most
;   popular fighting games implement their command detection.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. Defaults to 15
;   if omitted
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands examples are given below.
;
; [Command] ;Quarter circle forward + x
; name = "QCF_x"
; command = ~D, DF, F, x
;
; [Command] ;Half circle back + a
; name = "HCB_a"
; command = ~F, DF, D, DB, B, a
;
; [Command] ;Two quarter circles forward + y
; name = "2QCF_y"
; command = ~D, DF, F, D, DF, F, y
;
; [Command] ;Tap b rapidly
; name = "5b"
; command = b, b, b, b, b
; time = 30
;
; [Command] ;Charge back, then forward + z
; name = "charge_B_F_z"
; command = ~60$B, F, z
; time = 10
;
; [Command] ;Charge down, then up + c
; name = "charge_D_U_c"
; command = ~60$D, U, c
; time = 10
;

;-| Super Motions |--------------------------------------------------------
;The following two have the same name, but different motion.
;Either one will be detected by a "command = TripleKFPalm" trigger.
;Time is set to 20 (instead of default of 15) to make the move
;easier to do.
;
[command]
name = "QCF_a"
command = D,DF,F,a
time = 15

[command]
name = "QCF_b"
command = D,DF,F,b
time = 15

[command]
name = "QCF_c"
command = D,DF,F,c
time = 15

[command]
name = "up"
command = U
time = 99

[command]
name = "DU"
command = D,U
time = 15

[command]
name = "DUF"
command = D,UF
time = 15

[command]
name = "DUB"
command = D,UB
time = 15

[command]
name = "UB"
command = UB
time = 99

[command]
name = "UF"
command = UF
time = 99

;-| Special Motions |------------------------------------------------------
[Command]
name = "QCF_x"
command = ~D, DF, F, x

[Command]
name = "QCF_y"
command = ~D, DF, F, y

[Command]
name = "QCF_z"
command = ~D, DF, F, z

[Command]
name = "QCF_xa"
command = ~D, DF, F, x+a

[Command]
name = "QCF_yb"
command = ~D, DF, F, y+b

[Command]
name = "QCB_xa"
command = ~D, DB, B, x+a

[Command]
name = "QCB_x"
command = ~D, DB, B, x

[Command]
name = "QCB_y"
command = ~D, DB, B, y

[Command]
name = "QCB_z"
command = ~D, DB, B, z

[Command]
name = "hcb_a"
command = ~F, D, B, a
time = 23

[Command]
name = "finisher"
command = D, DB, B, y+b
time = 20

;-| Double Tap |-----------------------------------------------------------
[Command]
name = "FF"     ;Required (do not remove)
command = F, F
time = 10

[Command]
name = "BB"     ;Required (do not remove)
command = B, B
time = 10

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "recovery";Required (do not remove)
command = x+y
time = 1

;-| Dir + Button |---------------------------------------------------------
;[Command] an example
;name = "down_a"
;command = /$D,a
;time = 1

;-| Single Button |---------------------------------------------------------
[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

[Command]
name = "start"
command = s
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd";Required (do not remove)
command = /$F
time = 1

[Command]
name = "holdback";Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdup" ;Required (do not remove)
command = /$U
time = 1

[Command]
name = "holddown";Required (do not remove)
command = /$D
time = 1

[Command]
name = "holdx"
command = /x
time = 1

[Command]
name = "holdy"
command = /y
time = 1

[Command]
name = "holdz"
command = /z
time = 1

[Command]
name = "holda"
command = /a
time = 1

[Command]
name = "holdb"
command = /b
time = 1

[Command]
name = "holdc"
command = /c
time = 1

[Command]
name = "holdstart"
command = /s
time = 1


;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1, Label]           ;Change Label to any name you want to use to
;                               ;identify the state with.
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = command_name
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; Note: The order of state entry is important.
;   State entry with a certain command must come before another state
;   entry with a command that is the subset of the first.
;   For example, command "fwd_a" must be listed before "a", and
;   "fwd_ab" should come before both of the others.
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in.


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]

[State -1, Mugen 1.0 AI]
type = VarSet
trigger1 = AILevel
trigger1 = roundstate = 2
trigger1 = var(7) = 0
v = 7
value = AILevel
IgnoreHitPause = 1

[State -1, Mugen 1.0 AI]
type = VarSet
; Round over state
trigger1 = AILevel > 0
trigger1 = var(7)
trigger1 = roundstate = 4
; Round ending state and any enemies alive
trigger2 = AILevel > 0
trigger2 = var(7)
trigger2 = roundstate = 3
trigger2 = NumEnemy
trigger2 = enemy(0), alive || enemy (NumEnemy=2), alive
; Not AI
trigger3 = AILevel = 0
; Generating Infinite Meter
trigger4 = var(50) & 2048
v = 7
value = 0
IgnoreHitPause = 1


[State -1, Should be in meter battery mode]
type = ChangeState
triggerall = RoundState = [1,2]
triggerall = TeamMode = Simul
trigger1 = (var(50) & 2048)
trigger1 = StateNo != [190,192]
trigger1 = StateNo != [196,197]
value = 196


;---------------------------------------------------------------------------
; Human Controls
;---------------------------------------------------------------------------

;---------------------------------------------------------------------------
;The Fury of the Phoenix
[State -1, The Fury of the Phoenix]
type = ChangeState
value = 6000
triggerall = command = "finisher"
triggerall = !var(7)
triggerall = statetype != A
triggerall = statetype = S
triggerall = p2name != "Dark Phoenix" && p2name != "Phoenix Force"
triggerall = p3name != "Dark Phoenix" && p3name != "Phoenix Force"
triggerall = p4name != "Dark Phoenix" && p4name != "Phoenix Force"
triggerall = RoundNo > 1
triggerall = Power >= 2000
triggerall = life < (LifeMax * 500 / 1000)
trigger1 = ctrl
trigger2 = hitdefattr = SC, NA, SA, HA
trigger2 = stateno != [3050,3100]
trigger2 = movecontact = 1
;---------------------------------------------------------------------------
;Telekinetic Rock Shower (uses one super bar)
[State -1, Telekinetic Rock Shower]
type = ChangeState
value = 3000
triggerall = command = "QCF_xa"
triggerall = power >= 1000
triggerall = !var(7)
trigger1 = ctrl
trigger2 = hitdefattr = SC, NA, SA, HA
trigger2 = stateno != 6000 && stateno != [3050,3200]
trigger2 = movecontact = 1


;---------------------------------------------------------------------------
;Phoenix Super (uses one super bar)
[State -1, Phoenix Super]
type = ChangeState
value = 3100
triggerall = command = "QCF_yb"
triggerall = power >= 1000
triggerall = !var(7)
trigger1 = ctrl
trigger2 = hitdefattr = SC, NA, SA, HA
trigger2 = stateno != 6000 && stateno != [3050,3200]
trigger2 = movecontact = 1


;---------------------------------------------------------------------------
;Flare Mind Blast (uses one super bar)
[State -1, Flare Mind Blast]
type = ChangeState
value = 3200
triggerall = command = "QCB_xa"
triggerall = power >= 1000
triggerall = !var(7)
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = hitdefattr = SC, NA, SA, HA
trigger2 = stateno != 6000 && stateno != [3050,3200]
trigger2 = movecontact = 1

;===========================================================================
;---------------------------------------------------------------------------
;Mind Blast
[State -1, Mind Blast]
type = ChangeState
value = 1000
triggerall = (command = "QCF_x")
triggerall = !var(7)
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = (stateno = [200,299])
trigger2 = stateno != 440 ;Except for sweep kick
trigger2 = movecontact = 1


;---------------------------------------------------------------------------
;Phoenix Burst
[State -1, Phoenix Burst]
type = ChangeState
value = 1050
triggerall = (command = "QCF_y") || (command = "QCF_z")
triggerall = !var(7)
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = (stateno = [200,299])
trigger2 = stateno != 440 ;Except for sweep kick
trigger2 = movecontact = 1


;---------------------------------------------------------------------------
;Mind Blast (air)
[State -1, Mind Blast Air]
type = ChangeState
value = 1010
triggerall = !var(7)
triggerall = (command = "QCF_x") || (command = "QCF_y") || (command = "QCF_z")
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = (stateno = [400,499])
trigger2 = stateno != 440 ;Except for sweep kick
trigger2 = movecontact = 1


;---------------------------------------------------------------------------
;Telekinetic Shield
[State -1, Telekinetic Shield]
type = ChangeState
value = 1100
triggerall = !var(7)
triggerall = (command = "QCB_x") || (command = "QCB_y") || (command = "QCB_z")
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = (stateno = [200,299])
trigger2 = stateno != 440 ;Except for sweep kick
trigger2 = movecontact = 1

;---------------------------------------------------------------------------
;Phoenix Toe (short)
[State -1, Phoenix Toe]
type = ChangeState
value = 1300
triggerall = !var(7)
triggerall = command = "QCF_a"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = (stateno = [400,499])
trigger2 = stateno != 440 ;Except for sweep kick
trigger2 = movecontact = 1

;---------------------------------------------------------------------------
;Phoenix Toe (mid)
[State -1, Phoenix Toe]
type = ChangeState
value = 1310
triggerall = !var(7)
triggerall = command = "QCF_b"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = (stateno = [400,499])
trigger2 = stateno != 440 ;Except for sweep kick
trigger2 = movecontact = 1

;---------------------------------------------------------------------------
;Phoenix Toe (long)
[State -1, Phoenix Toe]
type = ChangeState
value = 1320
triggerall = !var(7)
triggerall = command = "QCF_c"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = (stateno = [400,499])
trigger2 = stateno != 440 ;Except for sweep kick
trigger2 = movecontact = 1

;---------------------------------------------------------------------------
;Phoenix Slide (short)
[State -1, Phoenix Slide]
type = ChangeState
value = 1200
triggerall = !var(7)
triggerall = command = "QCF_a"
trigger1 = StateType != A
trigger1 = ctrl
trigger2 = (stateno = [200,299])
trigger2 = stateno != 440 ;Except for sweep kick
trigger2 = movecontact = 1


;---------------------------------------------------------------------------
;Phoenix Slide (mid)
[State -1, Phoenix Slide]
type = ChangeState
value = 1210
triggerall = !var(7)
triggerall = command = "QCF_b"
trigger1 = StateType != A
trigger1 = ctrl
trigger2 = (stateno = [200,299])
trigger2 = stateno != 440 ;Except for sweep kick
trigger2 = movecontact = 1


;---------------------------------------------------------------------------
;Phoenix Slide (long)
[State -1, Phoenix Slide]
type = ChangeState
value = 1220
triggerall = command = "QCF_c"
triggerall = !var(7)
trigger1 = StateType != A
trigger1 = ctrl
trigger2 = (stateno = [200,299])
trigger2 = stateno != 440 ;Except for sweep kick
trigger2 = movecontact = 1

;---------------------------------------------------------------------------
;Ultemecia Dash
[State -1, Ultemecia Dash]
type = ChangeState
value = 1400
triggerall = !var(7)
triggerall = (command = "hcb_a")
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = (stateno = [200,299])
;trigger2 = stateno != 440 ;Except for sweep kick
trigger2 = movecontact = 1
;===========================================================================
;---------------------------------------------------------------------------
;Run Fwd
[State -1, Run Fwd]
type = ChangeState
value = 100
trigger1 = command = "FF"
trigger1 = StateType != A
trigger1 = StateNo != 100
trigger1 = ctrl

;---------------------------------------------------------------------------
;Run Back
;[State -1, Run Back]
;type = ChangeState
;value = 105
;trigger1 = command = "BB"
;trigger1 = statetype = S
;trigger1 = ctrl


;===========================================================================
;---------------------------------------------------------------------------
; s. Flying Start
[State -1, Flight]
type = ChangeState
value = 1700
triggerall = !var(7)
triggerall = StateType != A
triggerall = command = "start"
triggerall = !var(49)
trigger1 = ctrl
trigger2 = StateNo = [200,499]

;---------------------------------------------------------------------------
; j. Flying Start
[State -1, Air Flight]
type = ChangeState
value = 1701
triggerall = !var(7)
triggerall = StateType = A
triggerall = command = "start"
triggerall = Pos Y >= -270
triggerall = !var(49)
trigger1 = ctrl
trigger2 = StateNo = [600,699]

;---------------------------------------------------------------------------
; Flying End
[State -1, End Flight]
type = ChangeState
value = 1704
triggerall = !var(7)
triggerall = StateType = A
triggerall = command = "start"
triggerall = var(49) > 1
trigger1 = StateNo = 1702

;---------------------------------------------------------------------------
; Flying normal attacks
[State 1702, j.LP while Flying]
type = ChangeState
triggerall = !var(7)
trigger1 = StateNo = 1702
trigger1 = command = "x"
value = 600
[State 1702, j.LP while Flying]
type = ChangeState
triggerall = !var(7)
trigger1 = StateNo = 1702
trigger1 = command = "y"
value = 610
[State 1702, j.LP while Flying]
type = ChangeState
triggerall = !var(7)
trigger1 = StateNo = 1702
trigger1 = command = "z"
value = 620
[State 1702, j.LP while Flying]
type = ChangeState
triggerall = !var(7)
trigger1 = StateNo = 1702
trigger1 = command = "a"
value = 630
[State 1702, j.LP while Flying]
type = ChangeState
triggerall = !var(7)
trigger1 = StateNo = 1702
trigger1 = command = "b"
value = 640
[State 1702, j.LP while Flying]
type = ChangeState
triggerall = !var(7)
trigger1 = StateNo = 1702
trigger1 = command = "c"
value = 650

;---------------------------------------------------------------------------
;Stand Light Punch
[State -1, Stand Light Punch]
type = ChangeState
value = 200
triggerall = !var(7)
triggerall = command = "x"
triggerall = command != "holddown"
trigger1 = StateType != A
trigger1 = ctrl
trigger2 = stateno = 200
trigger2 = time > 6

;---------------------------------------------------------------------------
;Stand Medium Punch
[State -1, Stand Medium Punch]
type = ChangeState
value = 210
triggerall = !var(7)
triggerall = command = "y"
triggerall = command != "holddown"
trigger1 = StateType != A
trigger1 = ctrl
trigger2 = (stateno = 200) && movecontact = 1
trigger3 = (stateno = 230) && movecontact = 1

;---------------------------------------------------------------------------
;Stand Strong Punch
[State -1, Stand Strong Punch]
type = ChangeState
value = 220
triggerall = !var(7)
triggerall = numproj = 0
triggerall = command = "z"
triggerall = command != "holddown"
trigger1 = StateType != A
trigger1 = ctrl
trigger2 = (stateno = 200) && MoveContact = 1
trigger3 = (stateno = 210) && MoveContact = 1
trigger4 = (stateno = 230) && MoveContact = 1
trigger5 = (stateno = 240) && MoveContact = 1
;---------------------------------------------------------------------------
;Stand Light Kick
[State -1, Stand Light Kick]
type = ChangeState
value = 230
triggerall = !var(7)
triggerall = command = "a"
triggerall = command != "holddown"
trigger1 = StateType != A
trigger1 = ctrl
trigger2 = (stateno = 200) && MoveContact = 1

;---------------------------------------------------------------------------
;Standing Medium Kick
[State -1, Standing Medium Kick]
type = ChangeState
value = 240
triggerall = !var(7)
triggerall = command = "b"
triggerall = command != "holddown"
trigger1 = StateType != A
trigger1 = ctrl
trigger2 = (stateno = 200) && MoveContact = 1
trigger3 = (stateno = 210) && MoveContact = 1
trigger4 = (stateno = 230) && MoveContact = 1

;---------------------------------------------------------------------------
;Standing Strong Kick
[State -1, Standing Strong Kick]
type = ChangeState
value = 250
triggerall = !var(7)
triggerall = numproj = 0
triggerall = command = "c"
triggerall = command != "holddown"
trigger1 = StateType != A
trigger1 = ctrl
trigger2 = (stateno = 200) && MoveContact = 1
trigger3 = (stateno = 210) && MoveContact = 1
trigger4 = (stateno = 230) && MoveContact = 1
trigger5 = (stateno = 240) && MoveContact = 1
;--------------------------------------------------------------------------
;Super Jump
[State -1, Super Jump]
type = ChangeState
value = 41
triggerall = !var(7)
trigger1 = command = "DU"
trigger1 = StateType = S
trigger1 = ctrl
trigger2 = command = "DU"
trigger2 = StateType = C
trigger2 = ctrl
trigger3 = command = "up"
trigger3 = (stateno = 420) && Movecontact = 1
trigger4 = command = "DUF"
trigger4 = StateType = S
trigger4 = ctrl
trigger5 = command = "DUF"
trigger5 = StateType = C
trigger5 = ctrl
trigger6 = command = "DUB"
trigger6 = StateType = S
trigger6 = ctrl
trigger7 = command = "DUB"
trigger7 = StateType = C
trigger7 = ctrl
trigger8 = command = "UF"
trigger8 = (stateno = 420) && Movecontact = 1
trigger9 = command = "UB"
trigger9 = (stateno = 420) && Movecontact = 1

;---------------------------------------------------------------------------
;Crouching Light Punch
[State -1, Crouching Light Punch]
type = ChangeState
value = 400
triggerall = command = "x"
triggerall = command = "holddown"
triggerall = !var(7)
trigger1 = StateType != A
trigger1 = ctrl

;---------------------------------------------------------------------------
;Crouching Medium Punch
[State -1, Crouching Medium Punch]
type = ChangeState
value = 410
triggerall = command = "y"
triggerall = command = "holddown"
triggerall = !var(7)
trigger1 = StateType != A
trigger1 = ctrl
trigger2 = (stateno = 400) && MoveContact
trigger3 = (stateno = 430) && MoveContact

;---------------------------------------------------------------------------
;Crouching Strong Punch
[State -1, Crouching Strong Punch]
type = ChangeState
value = 420
triggerall = command = "z"
triggerall = command = "holddown"
triggerall = !var(7)
trigger1 = StateType != A
trigger1 = ctrl
trigger2 = (stateno = 400) && MoveContact
trigger3 = (stateno = 410) && MoveContact
trigger4 = (stateno = 430) && MoveContact
trigger5 = (stateno = 440) && MoveContact

;---------------------------------------------------------------------------
;Crouching Light Kick
[State -1, Crouching Light Kick]
type = ChangeState
value = 430
triggerall = command = "a"
triggerall = command = "holddown"
triggerall = !var(7)
trigger1 = StateType != A
trigger1 = ctrl
trigger2 = (stateno = 400) && MoveContact

;---------------------------------------------------------------------------
;Crouching Medium Kick
[State -1, Crouching Medium Kick]
type = ChangeState
value = 440
triggerall = command = "b"
triggerall = command = "holddown"
triggerall = !var(7)
trigger1 = StateType != A
trigger1 = ctrl
trigger2 = (stateno = 400) && MoveContact
trigger3 = (stateno = 410) && MoveContact
trigger4 = (stateno = 430) && MoveContact

;---------------------------------------------------------------------------
;Crouching Strong Kick
[State -1, Crouching Strong Kick]
type = ChangeState
value = 450
triggerall = command = "c"
triggerall = command = "holddown"
triggerall = !var(7)
trigger1 = StateType != A
trigger1 = ctrl
trigger2 = (stateno = 400) && MoveContact
trigger3 = (stateno = 410) && MoveContact
trigger4 = (stateno = 430) && MoveContact
trigger5 = (stateno = 440) && MoveContact

;---------------------------------------------------------------------------
;Jump Light Punch
[State -1, Jump Light Punch]
type = ChangeState
value = 600
triggerall = command = "x"
triggerall = !var(7)
trigger1 = statetype = A
trigger1 = ctrl

;---------------------------------------------------------------------------
;Jump Medium Punch
[State -1, Jump Medium Punch]
type = ChangeState
value = 610
triggerall = command = "y"
triggerall = !var(7)
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = (stateno = 600) && MoveContact
trigger3 = (stateno = 630) && MoveContact


;---------------------------------------------------------------------------
;Jump Strong Punch
[State -1, Jump Strong Punch]
type = ChangeState
value = 620
triggerall = !var(7)
triggerall = numproj = 0
triggerall = command = "z"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = (stateno = 600) && MoveContact
trigger3 = (stateno = 610) && MoveContact
trigger4 = (stateno = 630) && MoveContact
trigger5 = (stateno = 640) && MoveContact

;---------------------------------------------------------------------------
;Jump Light Kick
[State -1, Jump Light Kick]
type = ChangeState
value = 630
triggerall = command = "a"
triggerall = !var(7)
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = (stateno = 600) && MoveContact

;---------------------------------------------------------------------------
;Jump Medium Kick
[State -1, Jump Medium Kick]
type = ChangeState
value = 640
triggerall = !var(7)
triggerall = command = "b"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = (stateno = 600) && MoveContact
trigger3 = (stateno = 610) && MoveContact
trigger4 = (stateno = 630) && MoveContact

;---------------------------------------------------------------------------
;Jump Strong Kick
[State -1, Jump Strong Kick]
type = ChangeState
value = 650
triggerall = !var(7)
triggerall = numproj = 0
triggerall = command = "c"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = (stateno = 600) && MoveContact
trigger3 = (stateno = 610) && MoveContact
trigger4 = (stateno = 630) && MoveContact
trigger5 = (stateno = 640) && MoveContact

;---------------------------------------------------------------------------
;Power Charge
[State -1, Power Charge]
type = ChangeState
value = 198
triggerall = !var(7)
triggerall = command = "holdz" && command = "holdc"
triggerall = stateno != 3200
triggerall = stateno != 3201
triggerall = power < 3000
trigger1 = StateType != A
trigger1 = ctrl





;---------------------------------------------------------------------------
; AI Controls
;---------------------------------------------------------------------------


; ==========================
; Activate Infinites and AI Modes
; ==========================

;---------------------------------------------------------------------------
;Ultemecia Dash Infinite
[State -1, Activate Ultemecia Infinite]
type = VarSet
triggerall = var(7)
triggerall = !var(6)
trigger1 = ctrl ; Need to have control to actually do the dash immediately
; Not blocking target in the air
trigger1 = NumTarget
trigger1 = target, MoveType = H && target, statetype = A
trigger1 = target, StateNo != [120,155]
; Target will be in hitstun long enough to pick up the combo
trigger1 = ((target, GetHitVar(hitshaketime) + target, GetHitVar(hittime)) > 18) || (target, HitFall && !target, CanRecover)
; Target in a valid height range
; var(9) is 18 frames in target's future; There's no trigger for max? so ifelse is used instead
trigger1 = 1 || (var(9) := (18 - target, GetHitVar(hitshaketime)))
trigger1 = 1 || (var(9) := ifelse(var(9) < 0, 0, var(9)))
; fvar(10) is the target's y vel
trigger1 = 1 || (fvar(10) := ifelse((target, HitShakeOver), (target, vel y), (target, GetHitVar(yvel))))
trigger1 = -8 > (target, pos y  + (fvar(10) * var(9)) + (target, GetHitVar(yaccel) * (var(9) * (var(9) + 1) / 2)))
trigger1 = -95 < (target, pos y  + (fvar(10) * var(9)) + (target, GetHitVar(yaccel) * (var(9) * (var(9) + 1) / 2)))
; Just left an attack state
trigger1 = (PrevStateNo = [200,799]) || (PrevStateNo = [1000,1999]) || (PrevStateNo = [3000,4999])
trigger1 = time = 1
trigger1 = (random % 20 < var(7)) ; 5% to 40% chance per frame, AI1 to AI8
var(6) = 1

[State -1, Switch Infinites]
type = VarSet
triggerall = var(7)
triggerall = var(6) = 3
triggerall = ctrl
triggerall = p2life > 0
triggerall = statetype != A && statetype != L
triggerall = movetype != H
triggerall = StateNo != [120, 155]
; Don't stop the combo if we could gain more life
triggerall = life > (LifeMax * 700 / 1000)
; Target can't recover
triggerall = NumTarget
triggerall = (target, HitFall && !target, CanRecover)
; If combo has done at least 45% life of all enemies, switch to the more consistent infinite
; Because otherwise they might pop out of the combo at a random time, which would be worse
trigger1 = (var(10) - enemy(0), life) > (enemy(0), LifeMax * 450 / 1000)
trigger1 = (var(11) - enemy(NumEnemy=2), life) > (enemy(NumEnemy=2), LifeMax * 450 / 1000)
var(6) = 1

[State -1, Cancel Ultemecia Infinite]
type = VarSet
triggerall = var(7)
triggerall = var(6) = 1 ; Remember to set the Mode Id here
trigger1 = !NumTarget
trigger2 = NumTarget
trigger2 = target, StateNo = [120,155]
trigger3 = NumTarget
trigger3 = target, StateType = L
var(6) = 0

;---------------------------------------------------------------------------
;Slide Bubble Infinite
[State -1, Activate Slide Bubble Infinite]
type = VarSet
triggerall = var(7)
triggerall = !var(6)
trigger1 = ctrl ; Need to have control to pick up the combo
; Not blocking target in the air
trigger1 = NumTarget
trigger1 = target, MoveType = H && target, statetype = A
trigger1 = target, StateNo != [120,155]
; Target will be in hitstun long enough to pick up the combo
trigger1 = ((target, GetHitVar(hitshaketime) + target, GetHitVar(hittime)) > 7) || (target, HitFall && !target, CanRecover)
; Target close enough
trigger1 = (target, pos y > -60) || (target, HitFall && !target, CanRecover)
trigger1 = (target, pos x - 80 <= pos x) || P2BodyDist x <= 80
trigger1 = (target, pos x + 80 >= pos x) || P2BodyDist x <= 80
; Just left an attack state
trigger1 = (PrevStateNo = [200,799]) || (PrevStateNo = [1000,1999]) || (PrevStateNo = [3000,4999])
trigger1 = time = 1
trigger1 = (random % 16 < var(7)) ; 6.25% to 50% chance per frame, AI1 to AI8
var(6) = 3

[State -1, Cancel Slide Bubble Infinite]
type = VarSet
triggerall = var(7)
triggerall = var(6) = 3 ; Remember to set the Mode Id here
trigger1 = !NumTarget
trigger2 = NumTarget
trigger2 = target, StateNo = [120,155]
trigger3 = NumTarget
trigger3 = target, StateType = L
var(6) = 0

[State -1, Cancel trying to do super during infinite]
type = VarSet
triggerall = var(7)
triggerall = (var(50) & 16) = 16
trigger1 = !var(6)
trigger2 = !ctrl
var(50) = var(50) - 16

;---------------------------------------------------------------------------
; Long Range Flight
[State -1, Cancel Long Range Flight and Flight Rocks Infinite]
type = VarSet
triggerall = var(7)
triggerall = (var(6) = 4) || (var(6) = 5) ; Remember to set the Mode Id here
; If we're not flying anymore, usually by being hit out of it
trigger1 = MoveType = H
; Pressing buttons?
trigger2 = StateNo != [1700,1702]
trigger2 = !var(49)
trigger2 = StateNo != 40
trigger2 = !ctrl
; Dead enemies
trigger3 = (p2life <= 0) || (RoundState != 2)
; Enemy too close and don't have them in a combo
trigger4 = !NumTarget
trigger4 = abs(enemynear, pos x - pos x) < 160 || P2BodyDist x < 130
trigger4 = random > ((9 - var(7)) ** 3) ; 48.8% to 99.9% chance per frame, AI1 to AI8
trigger5 = NumTarget
trigger5 = target, StateNo = [120,155]
trigger5 = abs(enemynear, pos x - pos x) < 160 || P2BodyDist x < 130
trigger5 = random > ((9 - var(7)) ** 3) ; 48.8% to 99.9% chance per frame, AI1 to AI8
; Should be blocking
trigger6 = InGuardDist
trigger6 = random > ((9 - var(7)) ** 3) ; 48.8% to 99.9% chance per frame, AI1 to AI8
var(6) = 0

[State -1, Activate Long Range Flight]
type = VarSet
triggerall = var(7)
triggerall = !var(6)
; Enemy far enough away
triggerall = abs(enemynear, pos x - pos x) > 190 && P2BodyDist x > 160
triggerall = 1 || (var(15) := 0) ; Reset flight controls
; Have a fireball out
trigger1 = NumProjID(11000) = 1
trigger1 = (400 * random / 1000.) < var(7) ; 0.25% to 2% chance per frame, AI1 to AI8
; Much better odds with 2 fireballs out
trigger2 = NumProjID(11000) >= 2
trigger2 = (random % 40) < var(7) ; 2.5% to 20% chance per frame, AI1 to AI8
var(6) = 4

;---------------------------------------------------------------------------
; Flight Rocks Infinite
[State -1, Cancel Flight Rocks Infinite to Long Range Flight]
type = VarSet
triggerall = var(7)
triggerall = var(6) = 5 ; Remember to set the Mode Id here
triggerall = abs(enemynear, pos x - pos x) > 190 && P2BodyDist x > 160
trigger1 = !NumTarget
trigger2 = NumTarget
trigger2 = target, StateNo = [120,155]
var(6) = 4

[State -1, Cancel Flight Rocks Infinite to Long Range Flight]
type = VarSet
triggerall = var(7)
triggerall = var(6) = 5 ; Remember to set the Mode Id here
trigger1 = !NumTarget
trigger2 = NumTarget
trigger2 = target, StateNo = [120,155]
var(6) = 0

[State -1, Activate Flight Rocks Infinite]
type = VarSet
triggerall = var(7)
triggerall = var(6) = 4 ; Currently spamming rocks from fullscreen
trigger1 = NumTarget
trigger1 = target, StateNo != [120,155]
; Target must be pushed to the wall
trigger1 = target, BackEdgeBodyDist < 10
; Have fireballs out
trigger1 = NumProjID(221) >= 1
trigger1 = NumProjID(221) >= (var(52) - 1)
trigger1 = (400 * random / 1000.) < var(7) ; 0.25% to 2% chance per frame, AI1 to AI8
var(6) = 5
;---------------------------------------------------------------------------
;Run forward c.MK infinite
[State -1, Activate Run c.MK Infinite]
type = VarSet
triggerall = var(7)
triggerall = !var(6)
; Not blocking target in the air
triggerall = NumTarget
triggerall = target, MoveType = H
triggerall = target, statetype = S || target, statetype = C
triggerall = target, StateNo != [120,155]
; Target will be in hitstun long enough to pick up the combo
triggerall = (target, GetHitVar(hitshaketime) + target, GetHitVar(hittime)) > 3
; Just left an attack state
trigger1 = ctrl ; Need to have control to actually do the dash immediately
trigger1 = (PrevStateNo = [200,799]) || (PrevStateNo = [1000,1999]) || (PrevStateNo = [3000,4999])
trigger1 = time = 1
trigger1 = (random % 20 < var(7)) ; 5% to 40% chance per frame, AI1 to AI8
; Just hit with a normal
trigger2 = StateNo = [200,599]
trigger2 = (StateNo != [210,220]) && (StateNo != 250) && (StateNo != [420,430]) && (StateNo != 450) ; Some normals won't work
trigger2 = MoveHit = 1
trigger2 = (random % 20 < var(7)) ; 5% to 40% chance per frame, AI1 to AI8
var(6) = 6

[State -1, Switch Infinites]
type = VarSet
triggerall = var(7)
triggerall = var(6) = 6
triggerall = stateno = [200,599]
triggerall = MoveContact = 1
triggerall = power >= 2000 ; Need full meter because meatballs is required to combo 
triggerall = p2life > 0
triggerall = NumTarget
triggerall = target, BackEdgeDist <= 1 ; in the corner
; If combo has done at least 25% life of all enemies
triggerall = (var(10) - enemy(0), life) > (enemy(0), LifeMax * 250 / 1000)
triggerall = (var(11) - enemy(NumEnemy=2), life) > (enemy(NumEnemy=2), LifeMax * 250 / 1000)
; Switch to the more damaging infinite if
; An enemy has more life
trigger1 = (life * 1000 / LifeMax) < (enemy(0), life * 1000 / enemy(0), LifeMax)
trigger2 = (life * 1000 / LifeMax) < (enemy(NumEnemy=2), life * 1000 / enemy(NumEnemy=2), LifeMax)
; If combo has done at least 45% life of all enemies
trigger3 = (var(10) - enemy(0), life) > (enemy(0), LifeMax * 450 / 1000)
trigger3 = (var(11) - enemy(NumEnemy=2), life) > (enemy(NumEnemy=2), LifeMax * 450 / 1000)
var(6) = 3

[State -1, Cancel Run c.MK Infinite]
type = VarSet
triggerall = var(7)
triggerall = var(6) = 6 ; Remember to set the Mode Id here
trigger1 = !NumTarget
trigger2 = NumTarget
trigger2 = target, StateNo = [120,155]
trigger3 = NumTarget
trigger3 = target, StateType = L
var(6) = 0



[State -1, Cancel Flight State]
type = ChangeState
value = 1704
triggerall = var(7)
triggerall = var(6) != 4 ; Not in long range flight
triggerall = var(6) != 5 ; Not in flight infinite
triggerall = StateType = A
triggerall = var(49) > 1
trigger1 = StateNo = 1702


; ==========================
; Activate Walk toward target
; ==========================

[State -1, Walk forward on hit activate]
type = VarSet
triggerall = var(7)
triggerall = !(var(50) & (32 + 64)) ; Not already walking forward
triggerall = statetype != A && statetype != L
triggerall = ctrl
triggerall = NumTarget
triggerall = (target, pos x - pos x) * facing > 0 ; If target is in front
; Target is relatively close, the point is to apply pressure after plus normals
triggerall = (target, pos x - 80 <= pos x) || P2BodyDist x <= 60
triggerall = (target, pos x + 80 >= pos x) || P2BodyDist x <= 60
triggerall = (25.14 * random / 1000.0) < (var(7) ** 1.5) ; 4% to 90% chance per frame, AI1 to AI8
; Grounded target
trigger1 = target, StateType = S || target, StateType = C
; Airborne target is near the ground
trigger2 = target, StateType = A
trigger2 = target, pos y > -80
trigger2 = target, pos y <= 0
var(50) = var(50) | ifelse(random % 4 = 0, 64, 32) ; Run a quarter of the time

[State -1, Cancel trying to walk/run forward toward target]
type = VarSet
triggerall = var(7)
triggerall = (var(50) & (32 + 64))
trigger1 = !NumTarget
trigger2 = !ctrl
trigger3 = NumTarget
trigger3 = target, StateType = L
trigger4 = NumTarget
trigger4 = target, StateType = A
trigger4 = target, pos y < -80
var(50) = var(50) - (var(5) & (32 + 64)) ; Remove 32 and 64 flags


; ==========================
; AI Testing
; ==========================

;Run Fwd
[State -1, Run Fwd]
type = null;ChangeState
value = 100
triggerall = 0
triggerall = var(7)
trigger1 = StateType != A
trigger1 = StateNo != 100
trigger1 = ctrl

;---------------------------------------------------------------------------
;Phoenix Slide (long)
[State -1, AI Phoenix Slide when no target]
type = null;ChangeState
value = 1220
triggerall = 0
triggerall = var(7)
triggerall = var(6) = 3
triggerall = statetype != A
triggerall = p2life > 0
; If should be guarding, only attack 10% of the time
triggerall = !InGuardDist || (random % 10 = 0)
; Neutral game
triggerall = ctrl = 1
; No target
trigger1 = !NumTarget
trigger1 = 1 ; Put % odds to perform here
; Target is blocking and will recover about when the attack comes out (frame trap)
trigger2 = NumTarget
trigger2 = target, StateNo = [120,155]
trigger2 = (target, GetHitVar(hitshaketime) + target, GetHitVar(ctrltime) - target, time) < 6
trigger2 = 1 ; Put % odds to perform here


[State -1, Force AI to stand for testing]
type = null;ChangeState
value = 0
triggerall = 0
trigger1 = var(7)
trigger1 = ctrl
trigger1 = statetype != A && statetype != L
trigger1 = movetype != H

;---------------------------------------------------------------------------
;Phoenix Super (uses one super bar)
[State -1, AI Phoenix Super]
type = null;ChangeState
value = 3100
triggerall = 0
triggerall = var(7)
triggerall = power >= 1000
triggerall = p2life > 0
; Use randomly on hit when idle
;trigger1 = Random <= 100
trigger1 = ctrl = 1
trigger1 = NumTarget
trigger1 = target, MoveType = H && target, stateno != [120,155]
trigger1 = (target, GetHitVar(hitshaketime) + target, GetHitVar(hittime)) > 6


; ==========================
; The most important move
; ==========================

;---------------------------------------------------------------------------
;Phoenix Super (uses one super bar)
[State -1, AI Phoenix Super]
type = ChangeState
value = 3100
triggerall = var(7) && !var(6)
triggerall = power >= 1000
triggerall = p2life > 0
; Use randomly in neutral, with opponent far enough away to not get blown up
trigger1 = (640 * random / 1000.0) < (var(7) ** 2) ; 0.16% to 10% chance per frame, AI1 to AI8
trigger1 = ctrl = 1
trigger1 = abs(enemynear, pos x - pos x) > 120 || P2BodyDist x > 80
; Use randomly on hit
trigger2 = (640 * random / 1000.0) < (var(7) ** 2) ; 0.16% to 10% chance per frame, AI1 to AI8
trigger2 = hitdefattr = SC, NA, SA, HA
trigger2 = stateno != 6000 && stateno != [3050,3200]
trigger2 = movehit = 1
; Use randomly on hit when idle
trigger3 = (640 * random / 1000.0) < (var(7) ** 2) ; 0.16% to 10% chance per frame, AI1 to AI8
trigger3 = ctrl = 1
trigger3 = NumTarget
trigger3 = target, MoveType = H && target, stateno != [120,155]
trigger3 = (target, GetHitVar(hitshaketime) + target, GetHitVar(hittime)) > 6
; Use if meter is full and all opponents in hitstun
trigger4 = power >= 2000
trigger4 = ctrl = 1
trigger4 = NumEnemy
trigger4 = !Enemy(0), Alive || Enemy(0), MoveType = H
trigger4 = !Enemy(NumEnemy=2), Alive || Enemy(NumEnemy=2), MoveType = H
trigger4 = (random % 65) < (var(7) * var(7)) ; 1.5% to 98% chance per frame, AI1 to AI8
; Full meter, and at sufficienct distance
trigger5 = power >= 2000
trigger5 = ctrl = 1
trigger5 = p2bodydist X > 150
trigger5 = !InGuardDist
trigger5 = (var(50) & 7) < 7 ; Hit out of charge state less than 7 times
trigger5 = (random % ((9 - var(7)) * 10)) = 0 ; 1.25% to 10% chance per frame, AI1 to AI8

;---------------------------------------------------------------------------
;Phoenix Super (uses one super bar)
[State -1, AI Phoenix Super Finish Off Opponent]
type = ChangeState
value = 3100
triggerall = var(7)
triggerall = var(6) != 1 ; Don't during Ultemecia Infinite since it's reliable
triggerall = power >= 1000
triggerall = p2life > 0
triggerall = NumTarget
; Opponent has low enough life that this should kill them
triggerall = (target, life) < (target, LifeMax * (target, Const(data.defence) / 100.0) * 100 / 1000)
triggerall = target, MoveType = H && target, stateno != [120,155]
triggerall = ((target, GetHitVar(hitshaketime) + target, GetHitVar(hittime)) > 6) || (target, HitFall && !target, CanRecover)
triggerall = random > ((9 - var(7)) ** 3) ; 48.8% to 99.9% chance per frame, AI1 to AI8
trigger1 = ctrl = 1
trigger1 = 1 || (var(6) := 0) ; Reset AI Mode
trigger2 = hitdefattr = SC, NA, SA, HA
trigger2 = stateno != 6000 && stateno != [3050,3200]
trigger2 = movecontact = 1
trigger2 = 1 || (var(6) := 0) ; Reset AI Mode

;---------------------------------------------------------------------------
;Phoenix Super (uses one super bar)
[State -1, AI Phoenix Super Against 2 Opponents]
type = ChangeState
value = 3100
triggerall = var(7) ; No var(6) check, against two opponents the infinite super loop is more important
triggerall = power >= 1000
triggerall = p2life > 0
; Use if two alive opponents and all opponents in hitstun, the meter will regen
trigger1 = NumEnemy = 2
trigger1 = ctrl = 1
trigger1 = Enemy(0), Alive && Enemy(0), MoveType = H
trigger1 = Enemy(1), Alive && Enemy(1), MoveType = H
trigger1 = (random % 65) < (var(7) * var(7)) ; 1.5% to 98% chance per frame, AI1 to AI8
; Use if two alive opponents and at sufficienct distance
trigger2 = NumEnemy = 2
trigger2 = ctrl = 1
trigger2 = Enemy(0), Alive
trigger2 = Enemy(1), Alive
trigger2 = p2bodydist X > 150
trigger2 = !InGuardDist
trigger2 = (var(50) & 7) < 7 ; Hit out of charge state less than 7 times
trigger2 = (random % ((9 - var(7)) * 10)) = 0 ; 1.25% to 10% chance per frame, AI1 to AI8
; Use if two alive opponents at slightly less sufficienct distance
trigger3 = NumEnemy = 2
trigger3 = ctrl = 1
trigger3 = p2bodydist X > 120 && p2bodydist X < 150
trigger3 = !InGuardDist
trigger3 = Enemy(0), Alive && Enemy(1), Alive
trigger3 = (var(50) & 7) < 7 ; Hit out of charge state less than 7 times
trigger3 = (random % 200) < var(7) ; 0.5% to 4% chance per frame, AI1 to AI8

;---------------------------------------------------------------------------
;Phoenix Super (uses one super bar)
[State -1, AI Phoenix Super Glitch edition]
type = ChangeState
value = 3100
triggerall = var(7)
triggerall = power >= 1000
triggerall = Random <= 100
; Some new triggers to make it happen more intelligently
triggerall = PalNo = [11,12] ; Only glitch out (read: cheat) in 11/12p
triggerall = (MoveType = H && time >= 2) || !Alive ; Play normally unless taking damage/dead
triggerall = abs(enemynear, pos y - pos y) < 160 ; An enemy needs to be in range, seriously
triggerall = RoundState < 3 ; Don't keep doing it after the round ends
trigger2 = stateno != 6000 && stateno != [3050,3200]
triggerall = p2life > 0
trigger1 = ctrl = 1


; ==========================
; AI Combo Game
; ==========================

;---------------------------------------------------------------------------
;Telekinetic Shield
[State -1, AI Telekinetic Shield to make normals safe]
type = ChangeState
value = 1100
triggerall = var(7) && !var(6)
triggerall = statetype != A
triggerall = p2life > 0
; Cancel standing normals into this to make them super safe when they're blocked
trigger1 = (stateno = [200,299])
trigger1 = stateno != 440 ;Except for sweep kick
trigger1 = MoveGuarded = 1
trigger1 = (random % 20) < var(7) ; 5% to 40% chance per frame, AI1 to AI8

;---------------------------------------------------------------------------
;Standing Strong Kick
[State -1, AI s.HK Combo]
type = ChangeState
value = 250
triggerall = var(7)
triggerall = var(6) = 3
triggerall = numproj = 0
triggerall = p2life > 0
; Grounded not blocking target
triggerall = NumTarget
triggerall = target, StateType != A && target, StateType != L
; Combo from standing normals
trigger1 = (stateno = [200,240]) && MoveContact = 1
trigger1 = (enemynear, pos x - 80 <= pos x) || P2BodyDist x <= 65
trigger1 = (enemynear, pos x + 80 >= pos x) || P2BodyDist x <= 65
trigger1 = (random % 40) < var(7) ; 2.5% to 20% chance per frame, AI1 to AI8

;---------------------------------------------------------------------------
;Phoenix Slide (long)
[State -1, AI Phoenix Slide Combo]
type = ChangeState
value = 1220
triggerall = var(7) && !var(6)
triggerall = statetype != A
triggerall = p2life > 0
; Use on grounded opponents
triggerall = NumTarget
triggerall = target, MoveType = H && target, statetype != A && target, statetype != L
triggerall = target, StateNo != [120,155]
; Combo off standing normals
trigger1 = (stateno = [200,299])
trigger1 = stateno != 440 ;Except for sweep kick
trigger1 = movecontact = 1
trigger1 = (random % 40) < var(7) ; 2.5% to 20% chance per frame, AI1 to AI8
; Combo off standing normals (more likely at the edge of range)
trigger2 = (stateno = [200,299])
trigger2 = stateno != 440 ;Except for sweep kick
trigger2 = movecontact = 1
trigger2 = abs(target, pos x - pos x) > 90 || P2BodyDist x > 65
trigger2 = (random % 10) < var(7) ; 10% to 80% chance per frame, AI1 to AI8
; Attempt to link, opponent has to be pretty close so this hits before they recover
trigger3 = ctrl
trigger3 = (target, pos x - 100 <= pos x) || P2BodyDist x <= 100
trigger3 = (target, pos x + 100 >= pos x) || P2BodyDist x <= 100
; Target will be in hitstun long enough to pick up the combo
trigger3 = (target, GetHitVar(hitshaketime) + target, GetHitVar(hittime)) > 7
trigger3 = (random % ((9 - var(7)) * 5)) = 0 ; 2.5% to 20% chance per frame, AI1 to AI8
; Attempt to link on falling opponent
trigger4 = ctrl
trigger4 = (target, HitFall && !target, CanRecover)
trigger4 = (random % ((9 - var(7)) * 5)) = 0 ; 2.5% to 20% chance per frame, AI1 to AI8

;---------------------------------------------------------------------------
;Ultemecia Dash
[State -1, AI Ultemecia Dash Combo]
type = ChangeState
value = 1400
triggerall = var(7) && !var(6)
triggerall = statetype != A
triggerall = p2life > 0
triggerall = NumTarget
triggerall = (target, pos x - 200 <= pos x) || P2BodyDist x <= 200
triggerall = (target, pos x + 200 >= pos x) || P2BodyDist x <= 200
; On s.HK hit I guess whatever
trigger1 = stateno = 250 && movecontact = 1
trigger1 = (random % 10) < var(7) ; 10% to 80% chance per frame, AI1 to AI8

;---------------------------------------------------------------------------
;Telekinetic Rock Shower (uses one super bar)
[State -1, AI Telekinetic Rock Shower Combo]
type = ChangeState
value = 3000
triggerall = var(7)
triggerall = var(6) = 3
triggerall = ctrl
triggerall = p2life > 0
; Only if full life and full meter, we should use the other super below full meter
triggerall = life >= LifeMax
triggerall = power >= 2000
; Not blocking target
triggerall = NumTarget
triggerall = target, MoveType = H
triggerall = target, StateNo != [120,155]
triggerall = (random % ((9 - var(7)) * 5)) = 0 ; 2.5% to 20% chance per frame, AI1 to AI8
; Grounded target
trigger1 = target, statetype != A && target, statetype != L
trigger1 = (target, GetHitVar(hitshaketime) + target, GetHitVar(hittime)) > 14
; Airborne target
trigger2 = target, StateType = A
;	Hit will combo as a link
trigger2 = ((target, GetHitVar(hitshaketime) + target, GetHitVar(hittime)) > 14) || (target, HitFall && !target, CanRecover)
;	Target at least at a certain height
;	var(9) is 12 frames in target's future; There's no trigger for max? so ifelse is used instead
trigger2 = 1 || (var(9) := (12 - target, GetHitVar(hitshaketime)))
trigger2 = 1 || (var(9) := ifelse(var(9) < 0, 0, var(9)))
;	fvar(10) is the target's y vel
trigger2 = 1 || (fvar(10) := ifelse((target, HitShakeOver), (target, vel y), (target, GetHitVar(yvel))))
trigger2 = -5 > (target, pos y  + (fvar(10) * var(9)) + (target, GetHitVar(yaccel) * (var(9) * (var(9) + 1) / 2)))


; ==========================
; AI Air Neutral Game
; ==========================

;---------------------------------------------------------------------------
;Jump Strong Punch
[State -1, Jump Strong Punch]
type = ChangeState
value = 620
triggerall = var(7) && !var(6)
triggerall = numproj = 0
triggerall = ctrl
triggerall = statetype = A
triggerall = p2life > 0
; If should be guarding, only attack 10% of the time
triggerall = !InGuardDist || (random % 10 = 0)
; Round has just started
trigger1 = vel x < 0
trigger1 = pos y < -15
trigger1 = (GameTime - var(17)) <= 30
trigger1 = (random % 40) < var(7) ; 2.5% to 20% chance per frame, AI1 to AI8


; ==========================
; AI Neutral Game
; ==========================

;--------------------------------------------------------------------------
;Jump
[State -1, Jump back at the start of the round]
type = ChangeState
value = 40
triggerall = var(7)
trigger1 = var(17)
trigger1 = (GameTime - var(17)) < 5
trigger1 = StateType != A
trigger1 = ctrl
trigger1 = (p2life > 0) && (RoundState = 2)
; 1.6% to 12.9% chance per frame, AI1 to AI8
; Over 5 frames, this is a 49.88% chance of happening on AI8
trigger1 = (random % 62) < var(7)

;---------------------------------------------------------------------------
;Telekinetic Rock Shower (uses one super bar)
[State -1, AI Telekinetic Rock Shower Reversal]
type = ChangeState
value = 3000
triggerall = var(7)
triggerall = var(6) = 3
triggerall = ctrl
triggerall = p2life > 0
triggerall = power >= 1000
triggerall = var(12) > 0 ; Just recovered
triggerall = power >= (1500 - (var(51) * 50 / 3)) ; Reduce power requirement by 50 per time blown up
; If the enemy/ies are already being hit don't bother
trigger1 = !NumTarget
trigger1 = enemynear, MoveType != H
; 0.125% to 1% chance per frame, AI1 to AI8
; Odds multiplied by 2 for each time blown up
trigger1 = floor(800 * random / 1000.0) < (var(7) * (2 ** (var(51) / 3.0)))

;---------------------------------------------------------------------------
;Telekinetic Shield
[State -1, AI Telekinetic Shield in Neutral]
type = ChangeState
value = 1100
triggerall = var(7) && !var(6)
triggerall = statetype != A
triggerall = p2life > 0
; If should be guarding, only attack 10% of the time
triggerall = !InGuardDist || (random % 10 = 0)
; Neutral game
triggerall = ctrl = 1
; If the nearby idle enemy is high above, because there aren't any other antiairs
trigger1 = NumEnemy
trigger1 = enemynear, MoveType != H
trigger1 = -130 > (enemynear, pos y  + (enemynear, vel y * 9) + (enemynear, Const(movement.yaccel) * (9 * 10 / 2)))
trigger1 = (enemynear, pos x - 160 <= pos x) || P2BodyDist x <= 140
trigger1 = (enemynear, pos x + 160 >= pos x) || P2BodyDist x <= 140
trigger1 = (random % ((9 - var(7)) * 5)) = 0 ; 2.5% to 20% chance per frame, AI1 to AI8

;---------------------------------------------------------------------------
;Phoenix Burst
[State -1, AI Phoenix Burst in Neutral]
type = ChangeState
value = 1050
triggerall = var(7) && !var(6)
triggerall = statetype != A
triggerall = p2life > 0
; 5% less chance per time hit out of projectile state
triggerall = (random % 20) > var(54)
; If should be guarding, only attack 10% of the time
triggerall = !InGuardDist || (random % 10 = 0)
; Neutral game
triggerall = ctrl = 1
; Grounded or sort of near ground enemy is far away; this move is actually pretty safe at fullscreen
triggerall = enemynear, StateType != A || enemynear, pos y > -150
; Right side
;trigger1 = (enemynear, pos x - 250 <= pos x) || P2BodyDist x <= 250
trigger1 = (enemynear, pos x - 170 >= pos x) || P2BodyDist x > 150
trigger1 = (random % ((9 - var(7)) * 5)) = 0 ; 2.5% to 20% chance per frame, AI1 to AI8
; Left side
;trigger2 = (enemynear, pos x + 250 >= pos x) || P2BodyDist x <= 250
trigger2 = (enemynear, pos x + 170 <= pos x) || P2BodyDist x > 150
trigger2 = (random % ((9 - var(7)) * 5)) = 0 ; 2.5% to 20% chance per frame, AI1 to AI8

;---------------------------------------------------------------------------
;Ultemecia Dash
[State -1, AI Ultemecia Dash in Neutral]
type = ChangeState
value = 1400
triggerall = var(7) && !var(6)
triggerall = statetype != A
triggerall = p2life > 0
triggerall = (enemynear, pos x - 200 <= pos x) || P2BodyDist x <= 200
triggerall = (enemynear, pos x + 200 >= pos x) || P2BodyDist x <= 200
; Neutral game
trigger1 = ctrl = 1
trigger1 = !NumTarget
trigger1 = (enemynear, pos y > -90) && (enemynear, pos y < 20) ; Enemy is close to the ground
trigger1 = (random % ((9 - var(7)) * 10)) = 0 ; 1.25% to 10% chance per frame, AI1 to AI8
; Opponent in hitstun on the ground
trigger2 = ctrl = 1
trigger2 = NumTarget
trigger2 = target, MoveType = H && target, statetype != A && target, statetype != L
trigger2 = (random % ((9 - var(7)) * 10)) = 0 ; 1.25% to 10% chance per frame, AI1 to AI8

;---------------------------------------------------------------------------
;Phoenix Slide (long)
[State -1, AI Phoenix Slide H in Neutral]
type = ChangeState
value = 1220
triggerall = var(7) && !var(6)
triggerall = statetype != A
triggerall = p2life > 0
; If should be guarding, only attack 10% of the time
triggerall = !InGuardDist || (random % 10 = 0)
; Press less buttons if the opponent is parry happy
triggerall = (26.66 * random / 1000.0) >= var(53) ; 100% at 0 parries, 25% at the maximum 20 parries
; Neutral game
triggerall = ctrl = 1
; Don't use this below high life, especially when it could be parried
triggerall = life > (LifeMax * 750 / 1000)
; Grounded enemy is far away; this move is super plus on block so why not throw it out from fullscreen
; Because the opponent could parry it, use this slightly less to not give out free parries
; Right side
trigger1 = enemynear, StateType != A && enemynear, StateType != L
trigger1 = (enemynear, pos x - 250 <= pos x) || P2BodyDist x <= 250
trigger1 = (enemynear, pos x - 150 >= pos x)
trigger1 = (random % ((9 - var(7)) * 20)) = 0 ; 0.625% to 5% chance per frame, AI1 to AI8
; Left side
trigger1 = enemynear, StateType != A && enemynear, StateType != L
trigger2 = (enemynear, pos x + 250 >= pos x) || P2BodyDist x <= 250
trigger2 = (enemynear, pos x + 150 <= pos x)
trigger2 = (random % ((9 - var(7)) * 20)) = 0 ; 0.625% to 5% chance per frame, AI1 to AI8
; Close enough enemy that is grounded or close to the ground
trigger3 = enemynear, StateType != L
trigger3 = enemynear, StateType != A || enemynear, pos y > -20
trigger3 = (enemynear, pos x - 150 <= pos x) || P2BodyDist x <= 150
trigger3 = (enemynear, pos x + 150 >= pos x) || P2BodyDist x <= 150
trigger3 = (random % ((9 - var(7)) * 20)) = 0 ; 0.625% to 5% chance per frame, AI1 to AI8

;---------------------------------------------------------------------------
;Stand Light Kick
[State -1, AI s.LK in Neutral]
type = ChangeState
value = 230
triggerall = var(7) && !var(6)
triggerall = ctrl
triggerall = statetype != A
triggerall = p2life > 0
; If should be guarding, only attack 10% of the time
triggerall = !InGuardDist || (random % 10 = 0)
; Press less buttons if the opponent is parry happy
triggerall = (26.66 * random / 1000.0) >= var(53) ; 100% at 0 parries, 25% at the maximum 20 parries
; Neutral game, standing opponent
trigger1 = enemynear, StateType = S
trigger1 = (enemynear, pos x - 65 <= pos x) || P2BodyDist x <= 65
trigger1 = (enemynear, pos x + 65 >= pos x) || P2BodyDist x <= 65
trigger1 = (25.14 * random / 1000.0) < (var(7) ** 1.5) ; 4% to 90% chance per frame, AI1 to AI8
; Neutral game, crouching opponent
trigger2 = enemynear, StateType = C
trigger2 = (enemynear, pos x - 50 <= pos x) || P2BodyDist x <= 50
trigger2 = (enemynear, pos x + 50 >= pos x) || P2BodyDist x <= 50
trigger2 = (28.28 * random / 1000.0) < (var(7) ** 1.5) ; 3.5% to 80% chance per frame, AI1 to AI8
; Neutral game, airborne opponent
trigger3 = enemynear, StateType = A
trigger3 = (enemynear, pos y > -50) && (enemynear, pos y < 20)
trigger3 = (enemynear, pos x - 65 <= pos x) || P2BodyDist x <= 65
trigger3 = (enemynear, pos x + 65 >= pos x) || P2BodyDist x <= 65
trigger3 = (28.28 * random / 1000.0) < (var(7) ** 1.5) ; 3.5% to 80% chance per frame, AI1 to AI8

;---------------------------------------------------------------------------
;Stand Medium Kick
[State -1, AI s.MK in Neutral]
type = ChangeState
value = 240
triggerall = var(7) && !var(6)
triggerall = ctrl
triggerall = statetype != A
triggerall = p2life > 0
; If should be guarding, only attack 10% of the time
triggerall = !InGuardDist || (random % 10 = 0)
; Press less buttons if the opponent is parry happy
triggerall = (26.66 * random / 1000.0) >= var(53) ; 100% at 0 parries, 25% at the maximum 20 parries
; Neutral game, standing opponent
trigger1 = enemynear, StateType = S
trigger1 = (enemynear, pos x - 80 <= pos x) || P2BodyDist x <= 80
trigger1 = (enemynear, pos x + 80 >= pos x) || P2BodyDist x <= 80
trigger1 = (28.28 * random / 1000.0) < (var(7) ** 1.5) ; 3.5% to 80% chance per frame, AI1 to AI8
; Neutral game, airborne opponent
trigger2 = enemynear, StateType = A
trigger2 = (enemynear, pos y > -70) && (enemynear, pos y < 20)
trigger2 = (enemynear, pos x - 80 <= pos x) || P2BodyDist x <= 80
trigger2 = (enemynear, pos x + 80 >= pos x) || P2BodyDist x <= 80
trigger2 = (56.56 * random / 1000.0) < (var(7) ** 1.5) ; 1.75% to 40% chance per frame, AI1 to AI8

;---------------------------------------------------------------------------
;Crouching Medium Punch
[State -1, AI c.MP in Neutral]
type = ChangeState
value = 410
triggerall = var(7) && !var(6)
triggerall = ctrl
triggerall = statetype != A
triggerall = p2life > 0
; If should be guarding, only attack 10% of the time
triggerall = !InGuardDist || (random % 10 = 0)
; Press less buttons if the opponent is parry happy
triggerall = (26.66 * random / 1000.0) >= var(53) ; 100% at 0 parries, 25% at the maximum 20 parries
; Neutral game, grounded opponent
trigger1 = enemynear, StateType != A && enemynear, StateType != L
trigger1 = (enemynear, pos x - 65 <= pos x) || P2BodyDist x <= 60
trigger1 = (enemynear, pos x + 65 >= pos x) || P2BodyDist x <= 60
trigger1 = (25.14 * random / 1000.0) < (var(7) ** 1.5) ; 4% to 90% chance per frame, AI1 to AI8

;---------------------------------------------------------------------------
;Crouching Medium Kick
[State -1, AI c.MK in Neutral]
type = ChangeState
value = 440
triggerall = var(7) && !var(6)
triggerall = ctrl
triggerall = statetype != A
triggerall = p2life > 0
; If should be guarding, only attack 10% of the time
triggerall = !InGuardDist || (random % 10 = 0)
; Press less buttons if the opponent is parry happy
triggerall = (26.66 * random / 1000.0) >= var(53) ; 100% at 0 parries, 25% at the maximum 20 parries
; Neutral game, grounded opponent, at least a minimum distance away
triggerall = enemynear, StateType != A && enemynear, StateType != L
triggerall = (25.14 * random / 1000.0) < (var(7) ** 1.5) ; 4% to 90% chance per frame, AI1 to AI8
; Right side
trigger1 = (enemynear, pos x - 100 <= pos x) || P2BodyDist x <= 100
trigger1 = (enemynear, pos x - 65 >= pos x)
; Left side
trigger2 = (enemynear, pos x + 100 >= pos x) || P2BodyDist x <= 100
trigger2 = (enemynear, pos x + 65 <= pos x)


; ==========================
; AI Supers
; ==========================

;---------------------------------------------------------------------------
;The Fury of the Phoenix
[State -1, The Fury of the Phoenix]
type = null ; Disabled for AI because a fullscreen instant kill is kind of annoying
value = 6000
triggerall = var(7) && !var(6)
triggerall = p2life > 0
triggerall = statetype != A
triggerall = statetype = S
triggerall = p2name != "Dark Phoenix" && p2name != "Phoenix Force"
triggerall = p3name != "Dark Phoenix" && p3name != "Phoenix Force"
triggerall = p4name != "Dark Phoenix" && p4name != "Phoenix Force"
triggerall = RoundNo > 1
triggerall = Power >= 2000
triggerall = life < (LifeMax * 500 / 1000)
triggerall = Random <= 100
trigger1 = ctrl
trigger2 = hitdefattr = SC, NA, SA, HA
trigger2 =stateno != [3050,3100]
trigger2 = movecontact = 1

;---------------------------------------------------------------------------
;Flare Mind Blast (uses one super bar)
[State -1, Flare Mind Blast]
type = null ; This super is not as good as the other ones...
value = 3200
triggerall = var(7) && !var(6)
triggerall = power >= 1000
triggerall = statetype != A
triggerall = Random <= 100
triggerall = p2life > 0
trigger1 = ctrl = 1
trigger2 = hitdefattr = SC, NA, SA, HA
trigger2 = stateno != 6000 && stateno != [3050,3200]
trigger2 = movecontact = 1


; ==========================
; AI Specials
; ==========================

;---------------------------------------------------------------------------
;Mind Blast
[State -1, Mind Blast]
type = null ; Don't use this it's bad
value = 1000
triggerall = var(7) && !var(6)
triggerall = statetype != A
triggerall = Random <= 50
triggerall = p2life > 0
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Mind Blast (air)
[State -1, Mind Blast Air]
type = null ; Don't use this it's bad
value = 1010
triggerall = var(7) && !var(6)
triggerall = statetype = A
triggerall = p2life > 0
triggerall = Random <= 50
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Telekinetic Shield
[State -1, Telekinetic Shield Odds]
type = VarSet
triggerall = var(7)
triggerall = var(50) & 8 ; Lost a round
triggerall = 1 || (var(9) := 500) ; Default to 500
; Low life
trigger1 = life < (LifeMax * 650 / 1000)
; No bubble
trigger2 = !NumHelper(1101)
; Current bubble will disappear soon
trigger3 = NumHelper(1101)
trigger3 = ifelse((helper(1101), StateNo = 1102), 1, helper(1101), AnimTime <= 9)
var(9) = 1000

[State -1, Telekinetic Shield]
type = ChangeState
value = 1100
triggerall = var(7) && !var(6)
triggerall = statetype != A
triggerall = p2life > 0
triggerall = ctrl = 1
triggerall = (random % 65) < (var(7) * var(7)) ; 1.5% to 98% chance per frame, AI1 to AI8
; Haven't lost a round yet
trigger1 = !(var(50) & 8)
trigger1 = random < ifelse(life < (LifeMax * 650 / 1000), 500, 125) ; Higher odds if health too low
; Lost a round
trigger2 = var(50) & 8
trigger2 = random < var(9)

;----------------------------------------------------------------------------
;Phoenix Toe
[State -1, Phoenix Toe]
type = null;ChangeState ; disabled for now until I find a use for it
value = 1320
triggerall = var(7) && !var(6)
triggerall = statetype = A
triggerall = p2life > 0
triggerall = Random <= 100
trigger1 = ctrl = 1


; ==========================
; AI Normals
; ==========================

; Standing Normals
;---------------------------------------------------------------------------
;Stand Light Punch
[State -1, Stand Light Punch]
type = ChangeState
value = 200
triggerall = var(7) && !var(6)
triggerall = ctrl = 1
triggerall = (26.66 * random / 1000.0) < var(7) ; 3.75% to 30% chance per frame, AI1 to AI8
triggerall = StateType != A
triggerall = p2life > 0
; Press less buttons if the opponent is parry happy
triggerall = (26.66 * random / 1000.0) >= var(53) ; 100% at 0 parries, 25% at the maximum 20 parries
trigger1 = p2bodydist X <= 32

;---------------------------------------------------------------------------
;Stand Strong Punch
[State -1, Stand Strong Punch]
type = ChangeState
value = 220
triggerall = var(7) && !var(6)
triggerall = ctrl
triggerall = (26.66 * random / 1000.0) < var(7) ; 3.75% to 30% chance per frame, AI1 to AI8
triggerall = StateType != A
triggerall = p2life > 0
; Press less buttons if the opponent is parry happy
triggerall = (26.66 * random / 1000.0) >= var(53) ; 100% at 0 parries, 25% at the maximum 20 parries
trigger1 = p2bodydist X <= 32

;---------------------------------------------------------------------------
;Standing Strong Kick
[State -1, Standing Strong Kick]
type = ChangeState
value = 250
triggerall = var(7) && !var(6)
triggerall = ctrl
triggerall = (26.66 * random / 1000.0) < var(7) ; 3.75% to 30% chance per frame, AI1 to AI8
triggerall = StateType != A
triggerall = p2life > 0
; Press less buttons if the opponent is parry happy
triggerall = (26.66 * random / 1000.0) >= var(53) ; 100% at 0 parries, 25% at the maximum 20 parries
trigger1 = p2bodydist X <= 32

; Crouching Normals
;---------------------------------------------------------------------------
;Crouching Light Punch
[State -1, Crouching Light Punch]
type = ChangeState
value = 400
triggerall = var(7) && !var(6)
triggerall = ctrl
triggerall = (26.66 * random / 1000.0) < var(7) ; 3.75% to 30% chance per frame, AI1 to AI8
triggerall = StateType != A
triggerall = p2life > 0
; Press less buttons if the opponent is parry happy
triggerall = (26.66 * random / 1000.0) >= var(53) ; 100% at 0 parries, 25% at the maximum 20 parries
trigger1 = p2bodydist X <= 32

;---------------------------------------------------------------------------
;Crouching Strong Kick
[State -1, Crouching Strong Kick]
type = ChangeState
value = 450
triggerall = var(7) && !var(6)
triggerall = ctrl
triggerall = (26.66 * random / 1000.0) < var(7) ; 3.75% to 30% chance per frame, AI1 to AI8
triggerall = StateType != A
triggerall = p2life > 0
; Press less buttons if the opponent is parry happy
triggerall = (26.66 * random / 1000.0) >= var(53) ; 100% at 0 parries, 25% at the maximum 20 parries
trigger1 = p2bodydist X <= 32

; Aerial Normals
;---------------------------------------------------------------------------
;Jump Light Punch
[State -1, Jump Light Punch]
type = ChangeState
value = 600
triggerall = var(7) && !var(6)
triggerall = ctrl
triggerall = (26.66 * random / 1000.0) < var(7) ; 3.75% to 30% chance per frame, AI1 to AI8
triggerall = StateType != A
triggerall = p2life > 0
; Press less buttons if the opponent is parry happy
triggerall = (26.66 * random / 1000.0) >= var(53) ; 100% at 0 parries, 25% at the maximum 20 parries
trigger1 = p2bodydist X <= 32 && p2bodydist Y <= 15

;---------------------------------------------------------------------------
;Jump Light Kick
[State -1, Jump Light Kick]
type = ChangeState
value = 630
triggerall = var(7) && !var(6)
triggerall = ctrl
triggerall = (26.66 * random / 1000.0) < var(7) ; 3.75% to 30% chance per frame, AI1 to AI8
triggerall = statetype = A
triggerall = p2life > 0
; Press less buttons if the opponent is parry happy
trigger1 = (26.66 * random / 1000.0) >= var(53) ; 100% at 0 parries, 25% at the maximum 20 parries
trigger1 = p2bodydist X <= 32 && p2bodydist Y <= 15
trigger2 = (stateno = 600) && MoveContact

;---------------------------------------------------------------------------
;Jump Medium Punch
[State -1, Jump Medium Punch]
type = ChangeState
value = 610
triggerall = var(7) && !var(6)
triggerall = ctrl
triggerall = (26.66 * random / 1000.0) < var(7) ; 3.75% to 30% chance per frame, AI1 to AI8
triggerall = statetype = A
triggerall = p2life > 0
; Press less buttons if the opponent is parry happy
trigger1 = (26.66 * random / 1000.0) >= var(53) ; 100% at 0 parries, 25% at the maximum 20 parries
trigger1 = p2bodydist X <= 32 && p2bodydist Y <= 15
trigger2 = (stateno = 600) && MoveContact
trigger3 = (stateno = 630) && MoveContact

;---------------------------------------------------------------------------
;Jump Medium Kick
[State -1, Jump Medium Kick]
type = ChangeState
value = 640
triggerall = var(7) && !var(6)
triggerall = ctrl
triggerall = (26.66 * random / 1000.0) < var(7) ; 3.75% to 30% chance per frame, AI1 to AI8
triggerall = statetype = A
triggerall = p2life > 0
; Press less buttons if the opponent is parry happy
trigger1 = (26.66 * random / 1000.0) >= var(53) ; 100% at 0 parries, 25% at the maximum 20 parries
trigger1 = p2bodydist X <= 32 && p2bodydist Y <= 15
trigger2 = (stateno = 600) && MoveContact
trigger3 = (stateno = 610) && MoveContact
trigger4 = (stateno = 630) && MoveContact

;---------------------------------------------------------------------------
;Jump Strong Punch
[State -1, Jump Strong Punch]
type = ChangeState
value = 620
triggerall = var(7) && !var(6)
triggerall = numproj = 0
triggerall = ctrl
triggerall = (26.66 * random / 1000.0) < var(7) ; 3.75% to 30% chance per frame, AI1 to AI8
triggerall = statetype = A
triggerall = p2life > 0
trigger1 = p2bodydist X <= 32 && p2bodydist Y <= 15
trigger2 = (stateno = 600) && MoveContact
trigger3 = (stateno = 610) && MoveContact
trigger4 = (stateno = 630) && MoveContact
trigger5 = (stateno = 640) && MoveContact

;---------------------------------------------------------------------------
;Jump Strong Kick
[State -1, Jump Strong Kick]
type = ChangeState
value = 650
triggerall = var(7) && !var(6)
triggerall = numproj = 0
triggerall = ctrl
triggerall = (26.66 * random / 1000.0) < var(7) ; 3.75% to 30% chance per frame, AI1 to AI8
triggerall = statetype = A
triggerall = p2life > 0
trigger1 = p2bodydist X <= 32 && p2bodydist Y <= 15
trigger2 = (stateno = 600) && MoveContact
trigger3 = (stateno = 610) && MoveContact
trigger4 = (stateno = 630) && MoveContact
trigger5 = (stateno = 640) && MoveContact


; ==========================
; AI Walk Forward
; ==========================

[State -1, Run forward on hit]
type = ChangeState
value = 100
triggerall = var(7)
triggerall = !var(6)
triggerall = (var(50) & 64)
triggerall = (p2life > 0) && (RoundState = 2)
; If should be guarding, only move 10% of the time
triggerall = !InGuardDist || (random % 10 = 0)
trigger1 = StateType != A
trigger1 = StateNo != 100
trigger1 = ctrl
trigger1 = NumTarget
trigger1 = (target, pos x - pos x) * facing > 0 ; If target is still in front

[State -1, Walk forward on hit]
type = ChangeState
value = 20
triggerall = var(7)
triggerall = !var(6)
triggerall = (var(50) & 32)
triggerall = (p2life > 0) && (RoundState = 2)
; If should be guarding, only move 10% of the time
triggerall = !InGuardDist || (random % 10 = 0)
trigger1 = StateType != A
trigger1 = StateNo != 20
trigger1 = ctrl
trigger1 = NumTarget
trigger1 = (target, pos x - pos x) * facing > 0 ; If target is still in front


; ==========================
; AI Guard
; ==========================

[State -1, AI Start Blocking]
type = changestate
value = 120
triggerall = var(7)
triggerall = RoundState = 2 && ctrl
triggerall = stateno!=[120,155] ; Not already blocking
triggerall = InGuardDist
triggerall = !(enemynear, HitDefAttr = SCA, AT) ; Can't block throws, don't try
trigger1 = random > ((9 - var(7)) ** 3) ; 48.8% to 99.9% chance per frame, AI1 to AI8


; ==========================
; AI Other Stuff
; ==========================

;----------------------------------------------------------
;Super Jump
[State -1, Super Jump]
type = ChangeState
value = 41
triggerall = var(7) && !var(6)
triggerall = ctrl
triggerall = p2life > 0
trigger1 = (stateno = 420) && Movehit = 1

;---------------------------------------------------------------------------
;Power Charge
[State -1, Power Charge]
type = ChangeState
value = 198
triggerall = var(7) && !var(6)
triggerall = stateno != 3200
triggerall = stateno != 3201
triggerall = power < 2000
triggerall = ctrl
triggerall = StateType != A
triggerall = (p2life > 0) && (RoundState = 2)
triggerall = (var(50) & 7) < 7 ; Hit out of charge state less than 7 times
trigger1 = !InGuardDist
trigger1 = p2bodydist X > 150
trigger1 = (random % ((9 - var(7)) * 10)) = 0 ; 1.25% to 10% chance per frame, AI1 to AI8

;---------------------------------------------------------------------------
; Telekinetic Shield (for healing)
[State -1, Telekinetic Shield]
type = ChangeState
value = 1100 ; This regens health, so why not use it when far away?
; Also it's effectively invincible, and that's balanced
triggerall = var(7) && !var(6)
triggerall = stateno != 3200
triggerall = stateno != 3201
triggerall = life < LifeMax
triggerall = ctrl
triggerall = StateType != A
triggerall = p2life > 0
;triggerall = (var(50) & 7) < 7 ; Hit out of charge state less than 7 times
trigger1 = !InGuardDist
trigger1 = p2bodydist X > 140
trigger1 = (random % 20 < var(7)) ; 5% to 40% chance per frame, AI1 to AI8


; ==========================
; Infinites
; ==========================

;---------------------------------------------------------------------------
;Ultemecia Dash Infinite
[State -1, Telekinetic Rock Shower mid Infinite]
type = ChangeState
value = 3000
triggerall = var(7)
triggerall = var(6) = 1
triggerall = power >= 1500
triggerall = p2life > 0
triggerall = NumTarget
triggerall = (target, pos x - 200 <= pos x) || P2BodyDist x <= 200
triggerall = (target, pos x + 200 >= pos x) || P2BodyDist x <= 200
triggerall = ctrl
; Have an airbore target at least at a certain height
triggerall = target, MoveType = H && target, statetype = A
; var(9) is 12 frames in target's future; There's no trigger for max? so ifelse is used instead
triggerall = 1 || (var(9) := (12 - target, GetHitVar(hitshaketime)))
triggerall = 1 || (var(9) := ifelse(var(9) < 0, 0, var(9)))
; fvar(10) is the target's y vel
triggerall = 1 || (fvar(10) := ifelse((target, HitShakeOver), (target, vel y), (target, GetHitVar(yvel))))
triggerall = -56 < (target, pos y  + (fvar(10) * var(9)) + (target, GetHitVar(yaccel) * (var(9) * (var(9) + 1) / 2)))
triggerall = -24 > (target, pos y  + (fvar(10) * var(9)) + (target, GetHitVar(yaccel) * (var(9) * (var(9) + 1) / 2)))
triggerall = floor(10240 * random / 1000.0) < (var(7) ** 4) ; 0.01% to 40% chance per frame, AI1 to AI8
; Close to max life
trigger1 = life >= (LifeMax * 900 / 1000)
; Have at least ~500 life, and at least 33% more life that the target
trigger2 = life >= (LifeMax * 700 / 1000)
trigger2 = ((life * 1.0 / LifeMax) - 0.3) > (target, life * 1.0 / target, LifeMax)

[State -1, Phoenix Super mid Infinite]
type = ChangeState
value = 3100
triggerall = var(7)
triggerall = var(6) = 1
triggerall = power >= 1000
triggerall = p2life > 0
triggerall = NumTarget
triggerall = ctrl = 1
; Have an airbore target at least at a certain height
triggerall = target, MoveType = H && target, statetype = A
; fvar(10) is the target's y vel
triggerall = 1 || (fvar(10) := ifelse((target, HitShakeOver), (target, vel y), (target, GetHitVar(yvel))))
triggerall = (target, pos y  + (fvar(10) * 6) + (target, GetHitVar(yaccel) * (6 * 7 / 2))) < -10

; This keeps dropping the combo, so reduced odds
;triggerall = floor(10240 * random / 1000.0) < (var(7) ** 4) ; 0.01% to 40% chance per frame, AI1 to AI8
triggerall = (random % ((9 - var(7)) * 5)) = 0 ; 2.5% to 20% chance per frame, AI1 to AI8

; Low on life, healing is more important than the infinite
trigger1 = life < (LifeMax * 700 / 1000)
trigger1 = 1 || (var(6) := 0) ; Cancel the infinite
; At least some damage taken, and opponent is close enough that we should be able to pick up the combo
trigger2 = life < (LifeMax * 900 / 1000)
trigger2 = (target, pos x - 90 <= pos x) || P2BodyDist x <= 90
trigger2 = (target, pos x + 90 >= pos x) || P2BodyDist x <= 90
trigger2 = (target, pos y  + (fvar(10) * 6) + (target, GetHitVar(yaccel) * (6 * 7 / 2))) > -64
trigger2 = 1 || (var(6) := 0) ; Cancel the infinite

[State -1, AI Ultemecia Dash Infinite]
type = ChangeState
value = 1400
triggerall = var(7)
triggerall = var(6) = 1
triggerall = StateType != A
triggerall = p2life > 0
triggerall = NumTarget
triggerall = (target, pos x - 200 <= pos x) || P2BodyDist x <= 200
triggerall = (target, pos x + 200 >= pos x) || P2BodyDist x <= 200
triggerall = ctrl = 1
; Have an airbore target that will still be in hitstun
triggerall = target, MoveType = H && target, statetype = A
triggerall = ((target, GetHitVar(hitshaketime) + target, GetHitVar(hittime)) > 17) || (target, HitFall && !target, CanRecover)
; Target will fall within range in 17 ticks
; fvar(10) is the target's y vel
triggerall = 1 || (fvar(10) := ifelse((target, HitShakeOver), (target, vel y), (target, GetHitVar(yvel))))
triggerall = (target, pos y  + (fvar(10) * 17) + (target, GetHitVar(yaccel) * (17 * 18 / 2))) > -48
; Opponent will definitely be above the floor
trigger1 = (target, pos y  + (fvar(10) * 17) + (target, GetHitVar(yaccel) * (17 * 18 / 2))) < 0
trigger1 = floor(10240 * random / 1000.0) < (var(7) ** 4) ; 0.01% to 40% chance per frame, AI1 to AI8
; If opponent might recover before the hit comes out, increase the odds; still check if above the floor
trigger2 = target, HitFall && target, CanRecover
trigger2 = (target, GetHitVar(hitshaketime) + target, GetHitVar(hittime)) < 20
trigger2 = (target, pos y  + (fvar(10) * 17) + (target, GetHitVar(yaccel) * (17 * 18 / 2))) < 0
trigger2 = (random % 65) < (var(7) * var(7)) ; 1.5% to 98% chance per frame, AI1 to AI8
; If opponent will land before the attack hits, good AI will be more likely to realize that
trigger3 = random % 10 < (9 - var(7)) ; 80% to 10% chance per frame, AI1 to AI8
trigger3 = floor(10240 * random / 1000.0) < (var(7) ** 4) ; 0.01% to 40% chance per frame, AI1 to AI8

[State -1, AI Ultemecia Dash Infinite, Slide sometimes]
type = ChangeState
value = 1220
triggerall = var(7)
triggerall = var(6) = 1
triggerall = statetype != A
triggerall = p2life > 0
triggerall = NumTarget
triggerall = (target, pos x - 200 <= pos x) || P2BodyDist x <= 200
triggerall = (target, pos x + 200 >= pos x) || P2BodyDist x <= 200
triggerall = ctrl = 1
; Have an airbore target
triggerall = target, MoveType = H && target, statetype = A
; Tarhet will fall out of range within 17 ticks
; fvar(10) is the target's y vel
triggerall = 1 || (fvar(10) := ifelse((target, HitShakeOver), (target, vel y), (target, GetHitVar(yvel))))
; var(9) is 17 frames in target's future; There's no trigger for max? so ifelse is used instead
triggerall = 1 || (var(9) := (17 - target, GetHitVar(hitshaketime)))
triggerall = 1 || (var(9) := ifelse(var(9) < 0, 0, var(9)))
triggerall = -12 < (target, pos y  + (fvar(10) * var(9)) + (target, GetHitVar(yaccel) * (var(9) * (var(9) + 1) / 2)))
; But in 8 frames they'll still be above the floor
triggerall = 1 || (var(9) := (8 - target, GetHitVar(hitshaketime)))
triggerall = 1 || (var(9) := ifelse(var(9) < 0, 0, var(9)))
triggerall = 0 > (target, pos y  + (fvar(10) * var(9)) + (target, GetHitVar(yaccel) * (var(9) * (var(9) + 1) / 2)))
; Target y vel in 8 frames is positive, don't attack if they're still rising
triggerall = (fvar(10) + (var(9) * target, GetHitVar(yaccel))) > 0
; Opponent still in stun
triggerall = (target, GetHitVar(hitshaketime) + target, GetHitVar(hittime)) > 7 || (target, HitFall && !target, CanRecover)
trigger1 = (random % 65) < (var(7) * var(7)) ; 1.5% to 98% chance per frame, AI1 to AI8

[State -1, Run Closer for Infinite]
type = ChangeState
value = 100
triggerall = var(7)
triggerall = var(6) = 1
triggerall = (p2life > 0) && (RoundState = 2)
; If target is too far away, run closer
triggerall = NumTarget
triggerall = abs(target, pos x - pos x) > 200 || P2BodyDist x > 200
trigger1 = statetype != A && statetype != L
trigger1 = StateNo != 100
trigger1 = ctrl
trigger1 = random <= 800

[State -1, Force AI to stand for the Infinite]
type = ChangeState
value = 0
triggerall = var(7)
triggerall = var(6) = 1
triggerall = ctrl
trigger1 = statetype != A && statetype != L
trigger1 = movetype != H
trigger1 = StateNo != [120, 155]

;---------------------------------------------------------------------------
;Slide Bubble Infinite
[State -1, AI Telekinetic Shield oki]
type = ChangeState
value = 1100 ; Leaving this on instead of nulling it, in case the opponent happens to land
triggerall = var(7)
triggerall = var(6) = 3
triggerall = ctrl
triggerall = p2life > 0
triggerall = StateType != A
; Target landed on the ground
trigger1 = NumTarget
trigger1 = target, StateType = L
trigger1 = (random % ((9 - var(7)) * 5)) = 0 ; 2.5% to 20% chance per frame, AI1 to AI8

[State -1, Telekinetic Rock Shower on grounded opponent]
type = ChangeState
; Needed to get grounded opponents into the air for juggling after crouching normals
; Since crouching normals can't cancel into any specials
value = 3000
triggerall = var(7)
triggerall = var(6) = 3
triggerall = power >= 1000 ; Need full meter because meatballs is required to combo 
triggerall = p2life > 0
; Have a grounded target
triggerall = NumTarget
triggerall = target, MoveType = H
triggerall = target, statetype = S || target, statetype = C
trigger1 = stateno = [200,599]
trigger1 = MoveContact = 1

[State -1, AI Telekinetic Rock Shower in combo]
type = ChangeState
value = 3000
triggerall = var(7)
triggerall = var(6) = 3
triggerall = ctrl
triggerall = power >= 2000
triggerall = p2life > 0
; Airborne not blocking target in the corner
triggerall = NumTarget
triggerall = target, StateType = A
triggerall = target, BackEdgeDist < 20
; Target at least at a certain height
; var(9) is 12 frames in target's future; There's no trigger for max? so ifelse is used instead
triggerall = 1 || (var(9) := (12 - target, GetHitVar(hitshaketime)))
triggerall = 1 || (var(9) := ifelse(var(9) < 0, 0, var(9)))
; fvar(10) is the target's y vel
triggerall = 1 || (fvar(10) := ifelse((target, HitShakeOver), (target, vel y), (target, GetHitVar(yvel))))
triggerall = -5 > (target, pos y  + (fvar(10) * var(9)) + (target, GetHitVar(yaccel) * (var(9) * (var(9) + 1) / 2)))
; Hit will combo as a link
triggerall = (target, GetHitVar(hitshaketime) + target, GetHitVar(hittime)) > 12
triggerall = (random % ((9 - var(7)) * 5)) = 0 ; 2.5% to 20% chance per frame, AI1 to AI8
; Close to max life
trigger1 = life >= (LifeMax * 900 / 1000)
; Have at least half life, and at least 33% more life that the target
trigger2 = life >= (LifeMax * 700 / 1000)
trigger2 = ((life * 1.0 / LifeMax) - 0.3) > (target, life * 1.0 / target, LifeMax)

[State -1, AI Phoenix Super in combo]
type = null;ChangeState ; This is causing too many dropped combos, disabling until I can improve it
value = 3100
triggerall = 0
triggerall = var(7)
triggerall = var(6) = 3
triggerall = ctrl
triggerall = power >= 1000
triggerall = p2life > 0
; Airborne not blocking target in the corner
triggerall = NumTarget
triggerall = target, StateType = A
triggerall = target, BackEdgeDist < 20
; Hit will combo as a link
triggerall = ((target, GetHitVar(hitshaketime) + target, GetHitVar(hittime)) > 6) || (target, HitFall && !target, CanRecover)
triggerall = (random % ((9 - var(7)) * 10)) = 0 ; 1.25% to 10% chance per frame, AI1 to AI8
; At least some damage taken, and opponent is close enough that we should be able to pick up the combo
trigger1 = life < (LifeMax * 900 / 1000)
trigger1 = (target, pos x - 80 <= pos x) || P2BodyDist x <= 70
trigger1 = (target, pos x + 80 >= pos x) || P2BodyDist x <= 70
; AI would like to do super close to the ground, don't do normals early
trigger1 = 1 || (var(50) := (var(50) | 16))
; Target in a valid height range
; var(9) is 6 frames in target's future; There's no trigger for max? so ifelse is used instead
trigger1 = 1 || (var(9) := (6 - target, GetHitVar(hitshaketime)))
trigger1 = 1 || (var(9) := ifelse(var(9) < 0, 0, var(9)))
; fvar(10) is the target's y vel
trigger1 = 1 || (fvar(10) := ifelse((target, HitShakeOver), (target, vel y), (target, GetHitVar(yvel))))
trigger1 = -8 > (target, pos y  + (fvar(10) * var(9)) + (target, GetHitVar(yaccel) * (var(9) * (var(9) + 1) / 2)))
trigger1 = -20 < (target, pos y  + (fvar(10) * var(9)) + (target, GetHitVar(yaccel) * (var(9) * (var(9) + 1) / 2)))

[State -1, AI Phoenix Slide in combo, cancel from normal]
type = ChangeState
value = 1220
triggerall = var(7)
triggerall = var(6) = 3
triggerall = statetype != A
triggerall = p2life > 0
; Airborne not blocking target
triggerall = NumTarget
triggerall = target, StateType = A
; Combo from s.MK
triggerall = StateNo = 250 && MoveContact = 1
triggerall = random > ((9 - var(7)) ** 3) ; 48.8% to 99.9% chance per frame, AI1 to AI8
; by the time the opponent recovers they need to fall far enough to be hit
; var(9) is the target's hittime in the future
triggerall = 1 || (var(9) := target, GetHitVar(hittime))
triggerall = 1 || (var(9) := ifelse(var(9) < 0, 0, var(9)))
; fvar(10) is the target's y vel
triggerall = 1 || (fvar(10) := ifelse((target, HitShakeOver), (target, vel y), (target, GetHitVar(yvel))))
triggerall = -20 < (target, pos y  + (fvar(10) * var(9)) + (target, GetHitVar(yaccel) * (var(9) * (var(9) + 1) / 2)))
; If opponent is too far away
trigger1 = abs(target, pos x - pos x) > 60 || P2BodyDist x > 48
; Or too high up
;trigger2 = (target, pos y - pos y) >= -48
trigger2 = (target, pos y - pos y) < -5
trigger2 = (target, pos y - pos y) > -64
; var(9) is 7 frames in target's future; There's no trigger for max? so ifelse is used instead
trigger2 = 1 || (var(9) := (7 - target, GetHitVar(hitshaketime)))
trigger2 = 1 || (var(9) := ifelse(var(9) < 0, 0, var(9)))
trigger2 = -56 > (target, pos y  + (fvar(10) * var(9)) + (target, GetHitVar(yaccel) * (var(9) * (var(9) + 1) / 2)))

[State -1, AI Telekinetic Shield in combo, cancel from normal]
type = ChangeState
value = 1100
triggerall = var(7)
triggerall = var(6) = 3
triggerall = statetype != A
triggerall = p2life > 0
; Airborne not blocking target
triggerall = NumTarget
triggerall = target, StateType = A
; Combo from s.MK, close enough and not too high in the air
trigger1 = StateNo = 250 && MoveContact = 1
trigger1 = (enemynear, pos x - 56 <= pos x) || P2BodyDist x <= 56
trigger1 = (enemynear, pos x + 56 >= pos x) || P2BodyDist x <= 56
trigger1 = (target, pos y - pos y) > -80
trigger1 = random > ((9 - var(7)) ** 3) ; 48.8% to 99.9% chance per frame, AI1 to AI8

[State -1, AI Ultemecia Dash as link]
type = ChangeState
value = 1400 ; If opponent won't fall far enough for slide kick (ie just used meteors)
triggerall = var(7)
triggerall = var(6) = 3
triggerall = statetype != A
triggerall = p2life > 0
triggerall = NumTarget
triggerall = (target, pos x - 200 <= pos x) || P2BodyDist x <= 200
triggerall = (target, pos x + 200 >= pos x) || P2BodyDist x <= 200
triggerall = ctrl = 1
; Have an airbore target in the corner that will still be in hitstun
triggerall = target, MoveType = H && target, statetype = A
triggerall = target, BackEdgeDist <= 0
triggerall = ((target, GetHitVar(hitshaketime) + target, GetHitVar(hittime)) > 17) || (target, HitFall && !target, CanRecover)
; fvar(10) is the target's y vel
triggerall = 1 || (fvar(10) := ifelse((target, HitShakeOver), (target, vel y), (target, GetHitVar(yvel))))
; Opponent isn't in hitfall and will recover just after this attack would come out
trigger1 = target, HitFall && target, CanRecover
trigger1 = (target, GetHitVar(hitshaketime) + target, GetHitVar(hittime)) < 20
;	target y in 17 ticks is good
trigger1 = 1 || (var(9) := (17 - target, GetHitVar(hitshaketime)))
trigger1 = 1 || (var(9) := ifelse(var(9) < 0, 0, var(9)))
trigger1 = 0 > (target, pos y  + (fvar(10) * var(9)) + (target, GetHitVar(yaccel) * (var(9) * (var(9) + 1) / 2)))
trigger1 = -65 < (target, pos y  + (fvar(10) * var(9)) + (target, GetHitVar(yaccel) * (var(9) * (var(9) + 1) / 2)))
;	target y when they recover is too high for slide kick to pick up
trigger1 = 1 || (var(9) := target, GetHitVar(hittime))
trigger1 = 1 || (var(9) := ifelse(var(9) < 0, 0, var(9)))
trigger1 = -20 >= (target, pos y  + (fvar(10) * var(9)) + (target, GetHitVar(yaccel) * (var(9) * (var(9) + 1) / 2)))
trigger1 = (random % 65) < (var(7) * var(7)) ; 1.5% to 98% chance per frame, AI1 to AI8

[State -1, AI Phoenix Slide in combo, as link]
type = ChangeState
value = 1220
triggerall = var(7)
triggerall = var(6) = 3
triggerall = statetype != A
triggerall = p2life > 0
; Airborne not blocking target
triggerall = NumTarget
triggerall = target, StateType = A
; Combo from s.MK
triggerall = ctrl
triggerall = (random % 10 < var(7)) ; 10% to 80% chance per frame, AI1 to AI8
; by the time the opponent recovers they need to fall far enough to be hit
triggerall = 1 || (var(9) := target, GetHitVar(hittime))
triggerall = 1 || (var(9) := ifelse(var(9) < 0, 0, var(9)))
; fvar(10) is the target's y vel
triggerall = 1 || (fvar(10) := ifelse((target, HitShakeOver), (target, vel y), (target, GetHitVar(yvel))))
triggerall = -20 < (target, pos y  + (fvar(10) * var(9)) + (target, GetHitVar(yaccel) * (var(9) * (var(9) + 1) / 2)))
triggerall = target, GetHitVar(hittime) > 7
; If opponent is too far away
trigger1 = abs(target, pos x - pos x) > 60 || P2BodyDist x > 48
; Or too high up
;trigger2 = (target, pos y - pos y) >= -48
trigger2 = (target, pos y - pos y) < -5
trigger2 = (target, pos y - pos y) > -64
; var(9) is 7 frames in target's future; There's no trigger for max? so ifelse is used instead
trigger2 = 1 || (var(9) := (7 - target, GetHitVar(hitshaketime)))
trigger2 = 1 || (var(9) := ifelse(var(9) < 0, 0, var(9)))
trigger2 = -56 > (target, pos y  + (fvar(10) * var(9)) + (target, GetHitVar(yaccel) * (var(9) * (var(9) + 1) / 2)))
trigger2 = target, GetHitVar(hittime) <= 11 ; Let the opponent fall some to keep them closer to the ground

[State -1, AI s.MK in combo]
type = ChangeState
value = 240
triggerall = var(7)
triggerall = var(6) = 3
triggerall = ctrl
triggerall = statetype != A
triggerall = p2life > 0
; Airborne not blocking target
triggerall = NumTarget
triggerall = target, StateType = A
; Hit will combo as a link
triggerall = ((target, GetHitVar(hitshaketime) + target, GetHitVar(hittime)) > 5) || (target, HitFall && !target, CanRecover)
triggerall = (enemynear, pos x - 80 <= pos x) || P2BodyDist x <= 80
triggerall = (enemynear, pos x + 80 >= pos x) || P2BodyDist x <= 80
triggerall = (target, pos y - pos y) > -64
triggerall = (random % 10 < var(7)) ; 10% to 80% chance per frame, AI1 to AI8
; Let the opponent fall some to keep them closer to the ground
trigger1 = !target, HitFall || target, CanRecover
trigger1 = (target, GetHitVar(hitshaketime) + target, GetHitVar(hittime)) <= 9
; If trying to do super, don't do normals
trigger2 = (var(50) & 16) = 0
;	var(9) is 5 frames in target's future; There's no trigger for max? so ifelse is used instead
trigger2 = 1 || (var(9) := (5 - target, GetHitVar(hitshaketime)))
trigger2 = 1 || (var(9) := ifelse(var(9) < 0, 0, var(9)))
;	fvar(10) is the target's y vel
trigger2 = 1 || (fvar(10) := ifelse((target, HitShakeOver), (target, vel y), (target, GetHitVar(yvel))))
trigger2 = -24 < (target, pos y  + (fvar(10) * var(9)) + (target, GetHitVar(yaccel) * (var(9) * (var(9) + 1) / 2)))
trigger2 = -8 > (target, pos y  + (fvar(10) * var(9)) + (target, GetHitVar(yaccel) * (var(9) * (var(9) + 1) / 2)))

[State -1, AI s.LK in combo]
type = ChangeState
value = 230
triggerall = var(7)
triggerall = var(6) = 3
triggerall = ctrl
triggerall = statetype != A
triggerall = p2life > 0
; Airborne not blocking target
triggerall = NumTarget
triggerall = target, StateType = A
; Hit will combo as a link
triggerall = ((target, GetHitVar(hitshaketime) + target, GetHitVar(hittime)) > 2) || (target, HitFall && !target, CanRecover)
triggerall = (enemynear, pos x - 65 <= pos x) || P2BodyDist x <= 65
triggerall = (enemynear, pos x + 65 >= pos x) || P2BodyDist x <= 65
triggerall = (target, pos y - pos y) > -64
triggerall = (random % 10 < var(7)) ; 10% to 80% chance per frame, AI1 to AI8
;	fvar(10) is the target's y vel
triggerall = 1 || (fvar(10) := ifelse((target, HitShakeOver), (target, vel y), (target, GetHitVar(yvel))))
; Let the opponent fall some to keep them closer to the ground
trigger1 = !target, HitFall || target, CanRecover
trigger1 = (target, GetHitVar(hitshaketime) + target, GetHitVar(hittime)) <= 6
; If trying to do super, don't do normals
trigger2 = (var(50) & 16) = 0
;	var(9) is 2 frames in target's future; There's no trigger for max? so ifelse is used instead
trigger2 = 1 || (var(9) := (2 - target, GetHitVar(hitshaketime)))
trigger2 = 1 || (var(9) := ifelse(var(9) < 0, 0, var(9)))
trigger2 = -24 < (target, pos y  + (fvar(10) * var(9)) + (target, GetHitVar(yaccel) * (var(9) * (var(9) + 1) / 2)))
trigger2 = -8 > (target, pos y  + (fvar(10) * var(9)) + (target, GetHitVar(yaccel) * (var(9) * (var(9) + 1) / 2)))
; If they'll fall through the floor in 4 frames, make sure to hit them first
;	var(9) is 4 frames in target's future; There's no trigger for max? so ifelse is used instead
trigger3 = 1 || (var(9) := (4 - target, GetHitVar(hitshaketime)))
trigger3 = 1 || (var(9) := ifelse(var(9) < 0, 0, var(9)))
trigger3 = -5 < (target, pos y  + (fvar(10) * var(9)) + (target, GetHitVar(yaccel) * (var(9) * (var(9) + 1) / 2)))

[State -1, AI s.HK in combo]
type = ChangeState
value = 250
triggerall = var(7)
triggerall = var(6) = 3
triggerall = numproj = 0
triggerall = p2life > 0
; Airborne not blocking target
triggerall = NumTarget
triggerall = target, StateType = A
; Combo from standing normals
trigger1 = (stateno = [200,240]) && MoveContact = 1
trigger1 = (enemynear, pos x - 80 <= pos x) || P2BodyDist x <= 80
trigger1 = (enemynear, pos x + 80 >= pos x) || P2BodyDist x <= 80
trigger1 = random > ((9 - var(7)) ** 3) ; 48.8% to 99.9% chance per frame, AI1 to AI8

[State -1, Force AI to stand for the Infinite]
type = ChangeState
value = 0
triggerall = var(7)
triggerall = var(6) = 3
trigger1 = ctrl
trigger1 = statetype != A && statetype != L
trigger1 = movetype != H
trigger1 = StateNo != [120, 155]

;---------------------------------------------------------------------------
; Long Range Flight/Flight Rocks Infinite
[State -1, AI Start Long Range Flight (Ground)]
type = ChangeState
value = 1700
triggerall = var(7)
triggerall = var(6) = 4
triggerall = StateType != A
triggerall = !var(49)
triggerall = (random % 10) < var(7) ; 10% to 80% chance per frame, AI1 to AI8
trigger1 = ctrl
trigger2 = StateNo = [200,499]

[State -1, AI Start Long Range Flight (Jumping)]
type = ChangeState
value = 1701
triggerall = var(7)
triggerall = var(6) = 4
triggerall = StateType = A
triggerall = Pos Y >= -270
triggerall = !var(49)
triggerall = (random % 10) < var(7) ; 10% to 80% chance per frame, AI1 to AI8
trigger1 = ctrl
trigger2 = StateNo = [600,699]

[State -1, Haven't hit anything in a while]
type = VarSet
triggerall = var(7)
triggerall = var(6) = 4
triggerall = StateNo = 1702
trigger1 = var(16) < GameTime
trigger1 = GameTime - var(16) > 120 ; Haven't landed a hit in 2 seconds
; 1.25% to 10% chance per frame, AI1 to AI8
; Odds increased based on the number of rocks we've had onscreen at once
trigger1 = (random % 80) < (var(7) * (var(52) - 1))
; Don't throw another rock for 10 to 15 frames
; Rocks are a perfect blockstring, so we need to leave a gap if we want a hit
var(16) = GameTime + 15 + (random % 10)

[State -1, j.LP while Flying]
type = ChangeState
triggerall = var(7)
triggerall = (var(6) = 4) || (var(6) = 5)
triggerall = StateNo = 1702
triggerall = (var(6) != 5) || time >= 2 ; If trying to move in, add a delay in the rocks
; Enemy would be hit from this position
triggerall = (enemynear, pos y - (pos y - (65 - 5))) > (abs(enemynear, pos x - (pos x + facing * 62)) * 2 / 3.0)
triggerall = (enemynear, pos y - (pos y - (65 - (enemynear, Const(size.height) + 15)))) < (abs(enemynear, pos x - (pos x + facing * 62)) * 2 / 3.0)
triggerall = (random % 65) < (var(7) * var(7)) ; 1.5% to 98% chance per frame, AI1 to AI8
; No rock out already
trigger1 = NumProjId(221) = 0
; Opponent not blocking, blot out the sun
trigger2 = enemynear, StateNo != [120, 155]
; Definitely not enough rocks out already
trigger3 = NumProjId(221) < var(52) - 2
; Maybe not enough rocks out already
trigger4 = NumProjId(221) < var(52) - 1
trigger5 = random % 10 = 0 ; 10%
; We're past the no rocks time
trigger5 = GameTime >= var(16)
value = 620

;---------------------------------------------------------------------------
;Run forward c.MK infinite
[State -1, c.MP Odds]
type = null ; Effectively a VarSet
triggerall = var(7)
triggerall = var(6) = 6
triggerall = NumTarget
triggerall = 1 || (var(9) := 0) ; Default to 0
; Already landed multiple c.MPs
trigger1 = (var(50) & 384) = 384
;	85% against standing opponent, 75% against crouching
trigger1 = 1 || (var(9) := ifelse((target, StateType = C), 75, 85))
; Standing opponent
trigger2 = target, StateType = S
trigger2 = 1 || (var(9) := 10)
; Crouching opponent
trigger3 = target, StateType = S
trigger3 = 1 || (var(9) := 8)


[State -1, c.MP Infinite]
type = ChangeState
value = 410
triggerall = var(7)
triggerall = var(6) = 6
triggerall = statetype != A
triggerall = NumTarget
; Odds vary depending on if multiple c.MPs have hit successfully before and opponent state
triggerall = (random % 100) < var(9)
triggerall = ctrl
triggerall = NumTarget
triggerall = (enemynear, pos x - 80 <= pos x) || P2BodyDist x <= 60
triggerall = (enemynear, pos x + 80 >= pos x) || P2BodyDist x <= 60
triggerall = target, StateType = S || target, StateType = C
triggerall = (target, GetHitVar(hitshaketime) + target, GetHitVar(hittime)) <= 4
triggerall = random < (var(7) ** 3.3212) ; 0.1% to 99.9% chance per frame, AI1 to AI8
; On the last frame, use the full odds
trigger1 = (target, GetHitVar(hitshaketime) + target, GetHitVar(hittime)) = 2
; On any other frame, add a chance to mess up
trigger2 = random % 2 = 0

[State -1, c.MK Infinite]
type = ChangeState
value = 440
triggerall = var(7)
triggerall = var(6) = 6
triggerall = statetype != A
triggerall = ctrl
triggerall = NumTarget
triggerall = (enemynear, pos x - 90 <= pos x) || P2BodyDist x <= 75
triggerall = (enemynear, pos x + 90 >= pos x) || P2BodyDist x <= 75
triggerall = target, StateType = S || target, StateType = C
triggerall = (target, GetHitVar(hitshaketime) + target, GetHitVar(hittime)) <= 3
triggerall = random < (var(7) ** 3.3212) ; 0.1% to 99.9% chance per frame, AI1 to AI8
; On the last frame, use the full odds
trigger1 = (target, GetHitVar(hitshaketime) + target, GetHitVar(hittime)) = 2
; On any other frame, add a chance to mess up
trigger2 = random % 2 = 0

[State -1, Run Closer]
type = ChangeState
value = 100
triggerall = var(7)
triggerall = var(6) = 6
triggerall = (p2life > 0) && (RoundState = 2)
triggerall = NumTarget
triggerall = statetype != A
trigger1 = ctrl
trigger1 = StateNo != 100
trigger1 = random > ((9 - var(7)) ** 3) ; 48.8% to 99.9% chance per frame, AI1 to AI8

;---------------------------------------------------------------------------
;Phoenix Slide (long) Infinite
[State -1, AI Phoenix Slide H Infinite]
type = ChangeState
value = 1220
triggerall = var(7)
triggerall = var(6) = 2
triggerall = statetype != A
triggerall = p2life > 0
triggerall = (enemynear, pos x - 110 <= pos x) || P2BodyDist x <= 110
triggerall = (enemynear, pos x + 110 >= pos x) || P2BodyDist x <= 110
triggerall = ctrl = 1
; Have an airbore target that will fall within range in 7 ticks
triggerall = NumTarget
triggerall = target, MoveType = H && target, statetype = A
; fvar(10) is the target's y vel
triggerall = 1 || (fvar(10) := ifelse((target, HitShakeOver), (target, vel y), (target, GetHitVar(yvel))))
triggerall = (target, pos y  + (fvar(10) * 7) + (target, GetHitVar(yaccel) * (7 * 8 / 2))) > -25
triggerall = floor(10240 * random / 1000.0) < (var(7) ** 4) ; 0.01% to 40% chance per frame, AI1 to AI8
; Opponent will definitely be above the floor
trigger1 = (target, pos y  + (fvar(10) * 7) + (target, GetHitVar(yaccel) * (7 * 8 / 2))) < -5
; If opponent will land before the attack hits, good AI will be more likely to realize that
trigger2 = random % 10 < (9 - var(7)) ; 80% to 10% chance per frame, AI1 to AI8